from ._base import Base
from typing import Any, BinaryIO

__all__ = ["Users"]


class Users(Base):

    def login(
        self,
        id: str | None = None,
        login_id: str | None = None,
        token: str | None = None,
        device_id: str | None = None,
        ldap_only: bool | None = None,
        password: str | None = None,
        magic_link_token: str | None = None,
    ):
        """Login to Mattermost server

        id:
        login_id:
        token:
        device_id:
        ldap_only:
        password: The password used for email authentication.
        magic_link_token: Magic link token for passwordless guest authentication. When provided, authenticates the user using the magic link token instead of password. Requires guest magic link feature to be enabled.

        `Read in Mattermost API docs (users - Login) <https://developers.mattermost.com/api-documentation/#/operations/Login>`_

        """
        __options = {
            "id": id,
            "login_id": login_id,
            "token": token,
            "device_id": device_id,
            "ldap_only": ldap_only,
            "password": password,
            "magic_link_token": magic_link_token,
        }
        return self.client.post("""/api/v4/users/login""", options=__options)

    def login_by_cws_token(self, login_id: str | None = None, cws_token: str | None = None):
        """Auto-Login to Mattermost server using CWS token

        login_id:
        cws_token:

        `Read in Mattermost API docs (users - LoginByCwsToken) <https://developers.mattermost.com/api-documentation/#/operations/LoginByCwsToken>`_

        """
        __options = {"login_id": login_id, "cws_token": cws_token}
        return self.client.post("""/api/v4/users/login/cws""", options=__options)

    def login_sso_code_exchange(self, login_code: str, code_verifier: str, state: str):
        """Exchange SSO login code for session tokens

        login_code: Short-lived one-time code from SSO callback
        code_verifier: SAML verifier to prove code possession
        state: State parameter to prevent CSRF attacks

        `Read in Mattermost API docs (users - LoginSSOCodeExchange) <https://developers.mattermost.com/api-documentation/#/operations/LoginSSOCodeExchange>`_

        """
        __options = {"login_code": login_code, "code_verifier": code_verifier, "state": state}
        return self.client.post("""/api/v4/users/login/sso/code-exchange""", options=__options)

    def login_intune(self, options: Any):
        """Login with Microsoft Intune MAM
        `Read in Mattermost API docs (users - LoginIntune) <https://developers.mattermost.com/api-documentation/#/operations/LoginIntune>`_

        """
        return self.client.post("""/oauth/intune""", options=options)

    def logout(self):
        """Logout from the Mattermost server
        `Read in Mattermost API docs (users - Logout) <https://developers.mattermost.com/api-documentation/#/operations/Logout>`_

        """
        return self.client.post("""/api/v4/users/logout""")

    def create_user(
        self,
        email: str,
        username: str,
        first_name: str | None = None,
        last_name: str | None = None,
        nickname: str | None = None,
        position: str | None = None,
        timezone: Any | None = None,
        auth_data: str | None = None,
        auth_service: str | None = None,
        password: str | None = None,
        locale: str | None = None,
        props: dict[str, Any] | None = None,
        notify_props: Any | None = None,
    ):
        """Create a user

        email:
        username:
        first_name:
        last_name:
        nickname:
        position:
        timezone:
        auth_data: Service-specific authentication data, such as email address.
        auth_service: The authentication service, one of "email", "gitlab", "ldap", "saml", "office365", "google", and "".
        password: The password used for email authentication.
        locale:
        props:
        notify_props:

        `Read in Mattermost API docs (users - CreateUser) <https://developers.mattermost.com/api-documentation/#/operations/CreateUser>`_

        """
        __options = {
            "email": email,
            "username": username,
            "first_name": first_name,
            "last_name": last_name,
            "nickname": nickname,
            "position": position,
            "timezone": timezone,
            "auth_data": auth_data,
            "auth_service": auth_service,
            "password": password,
            "locale": locale,
            "props": props,
            "notify_props": notify_props,
        }
        return self.client.post("""/api/v4/users""", options=__options)

    def get_users(
        self,
        page: int | None = 0,
        per_page: int | None = 60,
        in_team: str | None = None,
        not_in_team: str | None = None,
        in_channel: str | None = None,
        not_in_channel: str | None = None,
        in_group: str | None = None,
        group_constrained: bool | None = None,
        without_team: bool | None = None,
        active: bool | None = None,
        inactive: bool | None = None,
        role: str | None = None,
        sort: str | None = None,
        roles: str | None = None,
        channel_roles: str | None = None,
        team_roles: str | None = None,
    ):
        """Get users

        page: The page to select.
        per_page: The number of users per page.
        in_team: The ID of the team to get users for.
        not_in_team: The ID of the team to exclude users for. Must not be used with "in_team" query parameter.
        in_channel: The ID of the channel to get users for.
        not_in_channel: The ID of the channel to exclude users for. Must be used with "in_channel" query parameter.
        in_group: The ID of the group to get users for. Must have ``manage_system`` permission.
        group_constrained: When used with ``not_in_channel`` or ``not_in_team``, returns only the users that are allowed to join the channel or team based on its group constrains.
        without_team: Whether or not to list users that are not on any team. This option takes precendence over ``in_team``, ``in_channel``, and ``not_in_channel``.
        active: Whether or not to list only users that are active. This option cannot be used along with the ``inactive`` option.
        inactive: Whether or not to list only users that are deactivated. This option cannot be used along with the ``active`` option.
        role: Returns users that have this role.
        sort: Sort is only available in conjunction with certain options below. The paging parameter is also always available.

        ##### ``in_team``
        Can be "", "last_activity_at" or "create_at".
        When left blank, sorting is done by username.
        Note that when "last_activity_at" is specified, an additional "last_activity_at" field will be returned in the response packet.
        *Minimum server version*: 4.0
        ##### ``in_channel``
        Can be "", "status".
        When left blank, sorting is done by username. ``status`` will sort by User's current status (Online, Away, DND, Offline), then by Username.
        *Minimum server version*: 4.7
        ##### ``in_group``
        Can be "", "display_name".
        When left blank, sorting is done by username. ``display_name`` will sort alphabetically by user's display name.
        *Minimum server version*: 7.7

        roles: Comma separated string used to filter users based on any of the specified system roles

        Example: ``?roles=system_admin,system_user`` will return users that are either system admins or system users

        *Minimum server version*: 5.26

        channel_roles: Comma separated string used to filter users based on any of the specified channel roles, can only be used in conjunction with ``in_channel``

        Example: ``?in_channel=4eb6axxw7fg3je5iyasnfudc5y&channel_roles=channel_user`` will return users that are only channel users and not admins or guests

        *Minimum server version*: 5.26

        team_roles: Comma separated string used to filter users based on any of the specified team roles, can only be used in conjunction with ``in_team``

        Example: ``?in_team=4eb6axxw7fg3je5iyasnfudc5y&team_roles=team_user`` will return users that are only team users and not admins or guests

        *Minimum server version*: 5.26


        `Read in Mattermost API docs (users - GetUsers) <https://developers.mattermost.com/api-documentation/#/operations/GetUsers>`_

        """
        __params = {
            "page": page,
            "per_page": per_page,
            "in_team": in_team,
            "not_in_team": not_in_team,
            "in_channel": in_channel,
            "not_in_channel": not_in_channel,
            "in_group": in_group,
            "group_constrained": group_constrained,
            "without_team": without_team,
            "active": active,
            "inactive": inactive,
            "role": role,
            "sort": sort,
            "roles": roles,
            "channel_roles": channel_roles,
            "team_roles": team_roles,
        }
        return self.client.get("""/api/v4/users""", params=__params)

    def permanent_delete_all_users(self):
        """Permanent delete all users
        `Read in Mattermost API docs (users - PermanentDeleteAllUsers) <https://developers.mattermost.com/api-documentation/#/operations/PermanentDeleteAllUsers>`_

        """
        return self.client.delete("""/api/v4/users""")

    def get_users_by_ids(self, options: list[str]):
        """Get users by ids
        `Read in Mattermost API docs (users - GetUsersByIds) <https://developers.mattermost.com/api-documentation/#/operations/GetUsersByIds>`_

        """
        return self.client.post("""/api/v4/users/ids""", options=options)

    def get_users_by_group_channel_ids(self, options: list[str]):
        """Get users by group channels ids
        `Read in Mattermost API docs (users - GetUsersByGroupChannelIds) <https://developers.mattermost.com/api-documentation/#/operations/GetUsersByGroupChannelIds>`_

        """
        return self.client.post("""/api/v4/users/group_channels""", options=options)

    def get_users_by_usernames(self, options: list[str]):
        """Get users by usernames
        `Read in Mattermost API docs (users - GetUsersByUsernames) <https://developers.mattermost.com/api-documentation/#/operations/GetUsersByUsernames>`_

        """
        return self.client.post("""/api/v4/users/usernames""", options=options)

    def search_users(
        self,
        term: str,
        team_id: str | None = None,
        not_in_team_id: str | None = None,
        in_channel_id: str | None = None,
        not_in_channel_id: str | None = None,
        in_group_id: str | None = None,
        group_constrained: bool | None = None,
        allow_inactive: bool | None = None,
        without_team: bool | None = None,
        limit: int | None = 100,
    ):
        """Search users

        term: The term to match against username, full name, nickname and email
        team_id: If provided, only search users on this team
        not_in_team_id: If provided, only search users not on this team
        in_channel_id: If provided, only search users in this channel
        not_in_channel_id: If provided, only search users not in this channel. Must specifiy ``team_id`` when using this option
        in_group_id: If provided, only search users in this group. Must have ``manage_system`` permission.
        group_constrained: When used with ``not_in_channel_id`` or ``not_in_team_id``, returns only the users that are allowed to join the channel or team based on its group constrains.
        allow_inactive: When ``true``, include deactivated users in the results
        without_team: Set this to ``true`` if you would like to search for users that are not on a team. This option takes precendence over ``team_id``, ``in_channel_id``, and ``not_in_channel_id``.
        limit: The maximum number of users to return in the results

        *Available as of server version 5.6. Defaults to ``100`` if not provided or on an earlier server version.*


        `Read in Mattermost API docs (users - SearchUsers) <https://developers.mattermost.com/api-documentation/#/operations/SearchUsers>`_

        """
        __options = {
            "term": term,
            "team_id": team_id,
            "not_in_team_id": not_in_team_id,
            "in_channel_id": in_channel_id,
            "not_in_channel_id": not_in_channel_id,
            "in_group_id": in_group_id,
            "group_constrained": group_constrained,
            "allow_inactive": allow_inactive,
            "without_team": without_team,
            "limit": limit,
        }
        return self.client.post("""/api/v4/users/search""", options=__options)

    def autocomplete_users(
        self, name: str, team_id: str | None = None, channel_id: str | None = None, limit: int | None = 100
    ):
        """Autocomplete users

        team_id: Team ID
        channel_id: Channel ID
        name: Username, nickname first name or last name
        limit: The maximum number of users to return in each subresult

        *Available as of server version 5.6. Defaults to ``100`` if not provided or on an earlier server version.*


        `Read in Mattermost API docs (users - AutocompleteUsers) <https://developers.mattermost.com/api-documentation/#/operations/AutocompleteUsers>`_

        """
        __params = {"team_id": team_id, "channel_id": channel_id, "name": name, "limit": limit}
        return self.client.get("""/api/v4/users/autocomplete""", params=__params)

    def get_known_users(self):
        """Get user IDs of known users
        `Read in Mattermost API docs (users - GetKnownUsers) <https://developers.mattermost.com/api-documentation/#/operations/GetKnownUsers>`_

        """
        return self.client.get("""/api/v4/users/known""")

    def get_total_users_stats(self):
        """Get total count of users in the system
        `Read in Mattermost API docs (users - GetTotalUsersStats) <https://developers.mattermost.com/api-documentation/#/operations/GetTotalUsersStats>`_

        """
        return self.client.get("""/api/v4/users/stats""")

    def get_total_users_stats_filtered(
        self,
        in_team: str | None = None,
        in_channel: str | None = None,
        include_deleted: bool | None = None,
        include_bots: bool | None = None,
        roles: str | None = None,
        channel_roles: str | None = None,
        team_roles: str | None = None,
    ):
        """Get total count of users in the system matching the specified filters

        in_team: The ID of the team to get user stats for.
        in_channel: The ID of the channel to get user stats for.
        include_deleted: If deleted accounts should be included in the count.
        include_bots: If bot accounts should be included in the count.
        roles: Comma separated string used to filter users based on any of the specified system roles

        Example: ``?roles=system_admin,system_user`` will include users that are either system admins or system users

        channel_roles: Comma separated string used to filter users based on any of the specified channel roles, can only be used in conjunction with ``in_channel``

        Example: ``?in_channel=4eb6axxw7fg3je5iyasnfudc5y&channel_roles=channel_user`` will include users that are only channel users and not admins or guests

        team_roles: Comma separated string used to filter users based on any of the specified team roles, can only be used in conjunction with ``in_team``

        Example: ``?in_team=4eb6axxw7fg3je5iyasnfudc5y&team_roles=team_user`` will include users that are only team users and not admins or guests


        `Read in Mattermost API docs (users - GetTotalUsersStatsFiltered) <https://developers.mattermost.com/api-documentation/#/operations/GetTotalUsersStatsFiltered>`_

        """
        __params = {
            "in_team": in_team,
            "in_channel": in_channel,
            "include_deleted": include_deleted,
            "include_bots": include_bots,
            "roles": roles,
            "channel_roles": channel_roles,
            "team_roles": team_roles,
        }
        return self.client.get("""/api/v4/users/stats/filtered""", params=__params)

    def get_user(self, user_id: str):
        """Get a user

        user_id: User GUID. This can also be "me" which will point to the current user.

        `Read in Mattermost API docs (users - GetUser) <https://developers.mattermost.com/api-documentation/#/operations/GetUser>`_

        """
        return self.client.get(f"/api/v4/users/{user_id}")

    def update_user(
        self,
        user_id: str,
        id: str,
        email: str,
        username: str,
        first_name: str | None = None,
        last_name: str | None = None,
        nickname: str | None = None,
        locale: str | None = None,
        position: str | None = None,
        timezone: Any | None = None,
        props: dict[str, Any] | None = None,
        notify_props: Any | None = None,
    ):
        """Update a user

        user_id: User GUID
        id:
        email:
        username:
        first_name:
        last_name:
        nickname:
        locale:
        position:
        timezone:
        props:
        notify_props:

        `Read in Mattermost API docs (users - UpdateUser) <https://developers.mattermost.com/api-documentation/#/operations/UpdateUser>`_

        """
        __options = {
            "id": id,
            "email": email,
            "username": username,
            "first_name": first_name,
            "last_name": last_name,
            "nickname": nickname,
            "locale": locale,
            "position": position,
            "timezone": timezone,
            "props": props,
            "notify_props": notify_props,
        }
        return self.client.put(f"/api/v4/users/{user_id}", options=__options)

    def delete_user(self, user_id: str):
        """Deactivate a user account.

        user_id: User GUID

        `Read in Mattermost API docs (users - DeleteUser) <https://developers.mattermost.com/api-documentation/#/operations/DeleteUser>`_

        """
        return self.client.delete(f"/api/v4/users/{user_id}")

    def patch_user(
        self,
        user_id: str,
        email: str | None = None,
        username: str | None = None,
        first_name: str | None = None,
        last_name: str | None = None,
        nickname: str | None = None,
        locale: str | None = None,
        position: str | None = None,
        timezone: Any | None = None,
        props: dict[str, Any] | None = None,
        notify_props: Any | None = None,
    ):
        """Patch a user

        user_id: User GUID
        email:
        username:
        first_name:
        last_name:
        nickname:
        locale:
        position:
        timezone:
        props:
        notify_props:

        `Read in Mattermost API docs (users - PatchUser) <https://developers.mattermost.com/api-documentation/#/operations/PatchUser>`_

        """
        __options = {
            "email": email,
            "username": username,
            "first_name": first_name,
            "last_name": last_name,
            "nickname": nickname,
            "locale": locale,
            "position": position,
            "timezone": timezone,
            "props": props,
            "notify_props": notify_props,
        }
        return self.client.put(f"/api/v4/users/{user_id}/patch", options=__options)

    def update_user_roles(self, user_id: str, roles: str):
        """Update a user's roles

        user_id: User GUID
        roles:

        `Read in Mattermost API docs (users - UpdateUserRoles) <https://developers.mattermost.com/api-documentation/#/operations/UpdateUserRoles>`_

        """
        __options = {"roles": roles}
        return self.client.put(f"/api/v4/users/{user_id}/roles", options=__options)

    def update_user_active(self, user_id: str, active: bool):
        """Activate or deactivate a user

        user_id: User GUID
        active:

        `Read in Mattermost API docs (users - UpdateUserActive) <https://developers.mattermost.com/api-documentation/#/operations/UpdateUserActive>`_

        """
        __options = {"active": active}
        return self.client.put(f"/api/v4/users/{user_id}/active", options=__options)

    def get_profile_image(self, user_id: str, _: float | None = None):
        """Get user's profile image

        user_id: User GUID
        _: Not used by the server. Clients can pass in the last picture update time of the user to potentially take advantage of caching

        `Read in Mattermost API docs (users - GetProfileImage) <https://developers.mattermost.com/api-documentation/#/operations/GetProfileImage>`_

        """
        __params = {"_": _}
        return self.client.get(f"/api/v4/users/{user_id}/image", params=__params)

    def set_profile_image(self, user_id: str, image: BinaryIO):
        """Set user's profile image

        user_id: User GUID
        image: The image to be uploaded

        `Read in Mattermost API docs (users - SetProfileImage) <https://developers.mattermost.com/api-documentation/#/operations/SetProfileImage>`_

        """
        __files = {"image": image}
        return self.client.post(f"/api/v4/users/{user_id}/image", files=__files)

    def set_default_profile_image(self, user_id: str):
        """Delete user's profile image

        user_id: User GUID

        `Read in Mattermost API docs (users - SetDefaultProfileImage) <https://developers.mattermost.com/api-documentation/#/operations/SetDefaultProfileImage>`_

        """
        return self.client.delete(f"/api/v4/users/{user_id}/image")

    def get_default_profile_image(self, user_id: str):
        """Return user's default (generated) profile image

        user_id: User GUID

        `Read in Mattermost API docs (users - GetDefaultProfileImage) <https://developers.mattermost.com/api-documentation/#/operations/GetDefaultProfileImage>`_

        """
        return self.client.get(f"/api/v4/users/{user_id}/image/default")

    def get_user_by_username(self, username: str):
        """Get a user by username

        username: Username

        `Read in Mattermost API docs (users - GetUserByUsername) <https://developers.mattermost.com/api-documentation/#/operations/GetUserByUsername>`_

        """
        return self.client.get(f"/api/v4/users/username/{username}")

    def reset_password(self, code: str, new_password: str):
        """Reset password

        code: The recovery code
        new_password: The new password for the user

        `Read in Mattermost API docs (users - ResetPassword) <https://developers.mattermost.com/api-documentation/#/operations/ResetPassword>`_

        """
        __options = {"code": code, "new_password": new_password}
        return self.client.post("""/api/v4/users/password/reset""", options=__options)

    def update_user_mfa(self, user_id: str, activate: bool, code: str | None = None):
        """Update a user's MFA

        user_id: User GUID
        activate: Use ``true`` to activate, ``false`` to deactivate
        code: The code produced by your MFA client. Required if ``activate`` is true

        `Read in Mattermost API docs (users - UpdateUserMfa) <https://developers.mattermost.com/api-documentation/#/operations/UpdateUserMfa>`_

        """
        __options = {"activate": activate, "code": code}
        return self.client.put(f"/api/v4/users/{user_id}/mfa", options=__options)

    def generate_mfa_secret(self, user_id: str):
        """Generate MFA secret

        user_id: User GUID

        `Read in Mattermost API docs (users - GenerateMfaSecret) <https://developers.mattermost.com/api-documentation/#/operations/GenerateMfaSecret>`_

        """
        return self.client.post(f"/api/v4/users/{user_id}/mfa/generate")

    def demote_user_to_guest(self, user_id: str):
        """Demote a user to a guest

        user_id: User GUID

        `Read in Mattermost API docs (users - DemoteUserToGuest) <https://developers.mattermost.com/api-documentation/#/operations/DemoteUserToGuest>`_

        """
        return self.client.post(f"/api/v4/users/{user_id}/demote")

    def promote_guest_to_user(self, user_id: str):
        """Promote a guest to user

        user_id: User GUID

        `Read in Mattermost API docs (users - PromoteGuestToUser) <https://developers.mattermost.com/api-documentation/#/operations/PromoteGuestToUser>`_

        """
        return self.client.post(f"/api/v4/users/{user_id}/promote")

    def convert_user_to_bot(self, user_id: str):
        """Convert a user into a bot

        user_id: User GUID

        `Read in Mattermost API docs (users - ConvertUserToBot) <https://developers.mattermost.com/api-documentation/#/operations/ConvertUserToBot>`_

        """
        return self.client.post(f"/api/v4/users/{user_id}/convert_to_bot")

    def check_user_mfa(self, login_id: str):
        """Check MFA

        login_id: The email or username used to login

        `Read in Mattermost API docs (users - CheckUserMfa) <https://developers.mattermost.com/api-documentation/#/operations/CheckUserMfa>`_

        """
        __options = {"login_id": login_id}
        return self.client.post("""/api/v4/users/mfa""", options=__options)

    def update_user_password(self, user_id: str, new_password: str, current_password: str | None = None):
        """Update a user's password

        user_id: User GUID
        current_password: The current password for the user
        new_password: The new password for the user

        `Read in Mattermost API docs (users - UpdateUserPassword) <https://developers.mattermost.com/api-documentation/#/operations/UpdateUserPassword>`_

        """
        __options = {"current_password": current_password, "new_password": new_password}
        return self.client.put(f"/api/v4/users/{user_id}/password", options=__options)

    def send_password_reset_email(self, email: str):
        """Send password reset email

        email: The email of the user

        `Read in Mattermost API docs (users - SendPasswordResetEmail) <https://developers.mattermost.com/api-documentation/#/operations/SendPasswordResetEmail>`_

        """
        __options = {"email": email}
        return self.client.post("""/api/v4/users/password/reset/send""", options=__options)

    def get_user_by_email(self, email: str):
        """Get a user by email

        email: User Email

        `Read in Mattermost API docs (users - GetUserByEmail) <https://developers.mattermost.com/api-documentation/#/operations/GetUserByEmail>`_

        """
        return self.client.get(f"/api/v4/users/email/{email}")

    def get_sessions(self, user_id: str):
        """Get user's sessions

        user_id: User GUID

        `Read in Mattermost API docs (users - GetSessions) <https://developers.mattermost.com/api-documentation/#/operations/GetSessions>`_

        """
        return self.client.get(f"/api/v4/users/{user_id}/sessions")

    def revoke_session(self, user_id: str, session_id: str):
        """Revoke a user session

        user_id: User GUID
        session_id: The session GUID to revoke.

        `Read in Mattermost API docs (users - RevokeSession) <https://developers.mattermost.com/api-documentation/#/operations/RevokeSession>`_

        """
        __options = {"session_id": session_id}
        return self.client.post(f"/api/v4/users/{user_id}/sessions/revoke", options=__options)

    def revoke_all_sessions(self, user_id: str):
        """Revoke all active sessions for a user

        user_id: User GUID

        `Read in Mattermost API docs (users - RevokeAllSessions) <https://developers.mattermost.com/api-documentation/#/operations/RevokeAllSessions>`_

        """
        return self.client.post(f"/api/v4/users/{user_id}/sessions/revoke/all")

    def attach_device_extra_props(
        self,
        device_id: str | None = None,
        deviceNotificationDisabled: str | None = None,
        mobileVersion: str | None = None,
    ):
        """Attach mobile device and extra props to the session object

        device_id: Mobile device id. For Android prefix the id with ``android:`` and Apple with ``apple:``
        deviceNotificationDisabled: Whether the mobile device has notifications disabled. Accepted values are "true" or "false".
        mobileVersion: Mobile app version. The version must be parseable as a semver.

        `Read in Mattermost API docs (users - AttachDeviceExtraProps) <https://developers.mattermost.com/api-documentation/#/operations/AttachDeviceExtraProps>`_

        """
        __options = {
            "device_id": device_id,
            "deviceNotificationDisabled": deviceNotificationDisabled,
            "mobileVersion": mobileVersion,
        }
        return self.client.put("""/api/v4/users/sessions/device""", options=__options)

    def get_user_audits(self, user_id: str):
        """Get user's audits

        user_id: User GUID

        `Read in Mattermost API docs (users - GetUserAudits) <https://developers.mattermost.com/api-documentation/#/operations/GetUserAudits>`_

        """
        return self.client.get(f"/api/v4/users/{user_id}/audits")

    def verify_user_email_without_token(self, user_id: str):
        """Verify user email by ID

        user_id: User GUID

        `Read in Mattermost API docs (users - VerifyUserEmailWithoutToken) <https://developers.mattermost.com/api-documentation/#/operations/VerifyUserEmailWithoutToken>`_

        """
        return self.client.post(f"/api/v4/users/{user_id}/email/verify/member")

    def verify_user_email(self, token: str):
        """Verify user email

        token: The token given to validate the email

        `Read in Mattermost API docs (users - VerifyUserEmail) <https://developers.mattermost.com/api-documentation/#/operations/VerifyUserEmail>`_

        """
        __options = {"token": token}
        return self.client.post("""/api/v4/users/email/verify""", options=__options)

    def send_verification_email(self, email: str):
        """Send verification email

        email: Email of a user

        `Read in Mattermost API docs (users - SendVerificationEmail) <https://developers.mattermost.com/api-documentation/#/operations/SendVerificationEmail>`_

        """
        __options = {"email": email}
        return self.client.post("""/api/v4/users/email/verify/send""", options=__options)

    def switch_account_type(
        self,
        current_service: str,
        new_service: str,
        email: str | None = None,
        password: str | None = None,
        mfa_code: str | None = None,
        ldap_id: str | None = None,
    ):
        """Switch login method

        current_service: The service the user currently uses to login
        new_service: The service the user will use to login
        email: The email of the user
        password: The password used with the current service
        mfa_code: The MFA code of the current service
        ldap_id: The LDAP/AD id of the user

        `Read in Mattermost API docs (users - SwitchAccountType) <https://developers.mattermost.com/api-documentation/#/operations/SwitchAccountType>`_

        """
        __options = {
            "current_service": current_service,
            "new_service": new_service,
            "email": email,
            "password": password,
            "mfa_code": mfa_code,
            "ldap_id": ldap_id,
        }
        return self.client.post("""/api/v4/users/login/switch""", options=__options)

    def get_login_type(self, id: str | None = None, login_id: str | None = None, device_id: str | None = None):
        """Get login authentication type

        id: The user ID (optional, can be used with login_id)
        login_id: The login ID (email, username, or unique identifier)
        device_id: The device ID for audit logging purposes

        `Read in Mattermost API docs (users - GetLoginType) <https://developers.mattermost.com/api-documentation/#/operations/GetLoginType>`_

        """
        __options = {"id": id, "login_id": login_id, "device_id": device_id}
        return self.client.post("""/api/v4/users/login/type""", options=__options)

    def create_user_access_token(self, user_id: str, description: str):
        """Create a user access token

        user_id: User GUID
        description: A description of the token usage

        `Read in Mattermost API docs (users - CreateUserAccessToken) <https://developers.mattermost.com/api-documentation/#/operations/CreateUserAccessToken>`_

        """
        __options = {"description": description}
        return self.client.post(f"/api/v4/users/{user_id}/tokens", options=__options)

    def get_user_access_tokens_for_user(self, user_id: str, page: int | None = 0, per_page: int | None = 60):
        """Get user access tokens

        user_id: User GUID
        page: The page to select.
        per_page: The number of tokens per page.

        `Read in Mattermost API docs (users - GetUserAccessTokensForUser) <https://developers.mattermost.com/api-documentation/#/operations/GetUserAccessTokensForUser>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get(f"/api/v4/users/{user_id}/tokens", params=__params)

    def get_user_access_tokens(self, page: int | None = 0, per_page: int | None = 60):
        """Get user access tokens

        page: The page to select.
        per_page: The number of tokens per page.

        `Read in Mattermost API docs (users - GetUserAccessTokens) <https://developers.mattermost.com/api-documentation/#/operations/GetUserAccessTokens>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get("""/api/v4/users/tokens""", params=__params)

    def revoke_user_access_token(self, token_id: str):
        """Revoke a user access token

        token_id: The user access token GUID to revoke

        `Read in Mattermost API docs (users - RevokeUserAccessToken) <https://developers.mattermost.com/api-documentation/#/operations/RevokeUserAccessToken>`_

        """
        __options = {"token_id": token_id}
        return self.client.post("""/api/v4/users/tokens/revoke""", options=__options)

    def get_user_access_token(self, token_id: str):
        """Get a user access token

        token_id: User access token GUID

        `Read in Mattermost API docs (users - GetUserAccessToken) <https://developers.mattermost.com/api-documentation/#/operations/GetUserAccessToken>`_

        """
        return self.client.get(f"/api/v4/users/tokens/{token_id}")

    def disable_user_access_token(self, token_id: str):
        """Disable personal access token

        token_id: The personal access token GUID to disable

        `Read in Mattermost API docs (users - DisableUserAccessToken) <https://developers.mattermost.com/api-documentation/#/operations/DisableUserAccessToken>`_

        """
        __options = {"token_id": token_id}
        return self.client.post("""/api/v4/users/tokens/disable""", options=__options)

    def enable_user_access_token(self, token_id: str):
        """Enable personal access token

        token_id: The personal access token GUID to enable

        `Read in Mattermost API docs (users - EnableUserAccessToken) <https://developers.mattermost.com/api-documentation/#/operations/EnableUserAccessToken>`_

        """
        __options = {"token_id": token_id}
        return self.client.post("""/api/v4/users/tokens/enable""", options=__options)

    def search_user_access_tokens(self, term: str):
        """Search tokens

        term: The search term to match against the token id, user id or username.

        `Read in Mattermost API docs (users - SearchUserAccessTokens) <https://developers.mattermost.com/api-documentation/#/operations/SearchUserAccessTokens>`_

        """
        __options = {"term": term}
        return self.client.post("""/api/v4/users/tokens/search""", options=__options)

    def update_user_auth(self, user_id: str, options: Any):
        """Update a user's authentication method

        user_id: User GUID

        `Read in Mattermost API docs (users - UpdateUserAuth) <https://developers.mattermost.com/api-documentation/#/operations/UpdateUserAuth>`_

        """
        return self.client.put(f"/api/v4/users/{user_id}/auth", options=options)

    def register_terms_of_service_action(self, user_id: str, serviceTermsId: str, accepted: str):
        """Records user action when they accept or decline custom terms of service

        user_id: User GUID
        serviceTermsId: terms of service ID on which the user is acting on
        accepted: true or false, indicates whether the user accepted or rejected the terms of service.

        `Read in Mattermost API docs (users - RegisterTermsOfServiceAction) <https://developers.mattermost.com/api-documentation/#/operations/RegisterTermsOfServiceAction>`_

        """
        __options = {"serviceTermsId": serviceTermsId, "accepted": accepted}
        return self.client.post(f"/api/v4/users/{user_id}/terms_of_service", options=__options)

    def get_user_terms_of_service(self, user_id: str):
        """Fetches user's latest terms of service action if the latest action was for acceptance.

        user_id: User GUID

        `Read in Mattermost API docs (users - GetUserTermsOfService) <https://developers.mattermost.com/api-documentation/#/operations/GetUserTermsOfService>`_

        """
        return self.client.get(f"/api/v4/users/{user_id}/terms_of_service")

    def revoke_sessions_from_all_users(self):
        """Revoke all sessions from all users.
        `Read in Mattermost API docs (users - RevokeSessionsFromAllUsers) <https://developers.mattermost.com/api-documentation/#/operations/RevokeSessionsFromAllUsers>`_

        """
        return self.client.post("""/api/v4/users/sessions/revoke/all""")

    def publish_user_typing(self, user_id: str, channel_id: str, parent_id: str | None = None):
        """Publish a user typing websocket event.

        user_id: User GUID
        channel_id: The id of the channel to which to direct the typing event.
        parent_id: The optional id of the root post of the thread to which the user is replying. If unset, the typing event is directed at the entire channel.

        `Read in Mattermost API docs (users - PublishUserTyping) <https://developers.mattermost.com/api-documentation/#/operations/PublishUserTyping>`_

        """
        __options = {"channel_id": channel_id, "parent_id": parent_id}
        return self.client.post(f"/api/v4/users/{user_id}/typing", options=__options)

    def get_uploads_for_user(self, user_id: str):
        """Get uploads for a user

        user_id: The ID of the user. This can also be "me" which will point to the current user.

        `Read in Mattermost API docs (users - GetUploadsForUser) <https://developers.mattermost.com/api-documentation/#/operations/GetUploadsForUser>`_

        """
        return self.client.get(f"/api/v4/users/{user_id}/uploads")

    def get_channel_members_with_team_data_for_user(
        self, user_id: str, page: int | None = None, per_page: int | None = 60
    ):
        """Get all channel members from all teams for a user

        user_id: The ID of the user. This can also be "me" which will point to the current user.
        page: Page specifies which part of the results to return, by perPage.
        per_page: The size of the returned chunk of results.

        `Read in Mattermost API docs (users - GetChannelMembersWithTeamDataForUser) <https://developers.mattermost.com/api-documentation/#/operations/GetChannelMembersWithTeamDataForUser>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get(f"/api/v4/users/{user_id}/channel_members", params=__params)

    def migrate_auth_to_ldap(self, from_: str, match_field: str, force: bool):
        """Migrate user accounts authentication type to LDAP.

        from: The current authentication type for the matched users.
        match_field: Foreign user field name to match.
        force:

        `Read in Mattermost API docs (users - MigrateAuthToLdap) <https://developers.mattermost.com/api-documentation/#/operations/MigrateAuthToLdap>`_

        """
        __options = {"from": from_, "match_field": match_field, "force": force}
        return self.client.post("""/api/v4/users/migrate_auth/ldap""", options=__options)

    def migrate_auth_to_saml(self, from_: str, matches: dict[str, Any], auto: bool):
        """Migrate user accounts authentication type to SAML.

        from: The current authentication type for the matched users.
        matches: Users map.
        auto:

        `Read in Mattermost API docs (users - MigrateAuthToSaml) <https://developers.mattermost.com/api-documentation/#/operations/MigrateAuthToSaml>`_

        """
        __options = {"from": from_, "matches": matches, "auto": auto}
        return self.client.post("""/api/v4/users/migrate_auth/saml""", options=__options)

    def get_users_with_invalid_emails(self, page: int | None = 0, per_page: int | None = 60):
        """Get users with invalid emails

        page: The page to select.
        per_page: The number of users per page.

        `Read in Mattermost API docs (users - GetUsersWithInvalidEmails) <https://developers.mattermost.com/api-documentation/#/operations/GetUsersWithInvalidEmails>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get("""/api/v4/users/invalid_emails""", params=__params)

    def reset_password_failed_attempts(self):
        """Reset the failed password attempts for a user
        `Read in Mattermost API docs (users - resetPasswordFailedAttempts) <https://developers.mattermost.com/api-documentation/#/operations/resetPasswordFailedAttempts>`_

        """
        return self.client.post(f"/api/v4/users/{user_id}/reset_failed_attempts")

    def convert_bot_to_user(
        self,
        bot_user_id: str,
        email: str | None = None,
        username: str | None = None,
        password: str | None = None,
        first_name: str | None = None,
        last_name: str | None = None,
        nickname: str | None = None,
        locale: str | None = None,
        position: str | None = None,
        props: dict[str, Any] | None = None,
        notify_props: Any | None = None,
    ):
        """Convert a bot into a user

        bot_user_id: Bot user ID
        email:
        username:
        password:
        first_name:
        last_name:
        nickname:
        locale:
        position:
        props:
        notify_props:

        `Read in Mattermost API docs (users - ConvertBotToUser) <https://developers.mattermost.com/api-documentation/#/operations/ConvertBotToUser>`_

        """
        __options = {
            "email": email,
            "username": username,
            "password": password,
            "first_name": first_name,
            "last_name": last_name,
            "nickname": nickname,
            "locale": locale,
            "position": position,
            "props": props,
            "notify_props": notify_props,
        }
        return self.client.post(f"/api/v4/bots/{bot_user_id}/convert_to_user", options=__options)

    def get_server_limits(self):
        """Gets the server limits for the server
        `Read in Mattermost API docs (users - GetServerLimits) <https://developers.mattermost.com/api-documentation/#/operations/GetServerLimits>`_

        """
        return self.client.get("""/api/v4/limits/server""")



from ._base import Base
from typing import Any, BinaryIO

__all__ = ["System"]


class System(Base):

    def get_supported_timezone(self):
        """Retrieve a list of supported timezones
        `Read in Mattermost API docs (system - GetSupportedTimezone) <https://developers.mattermost.com/api-documentation/#/operations/GetSupportedTimezone>`_

        """
        return self.client.get("""/api/v4/system/timezones""")

    def get_ping(
        self,
        get_server_status: bool | None = None,
        device_id: str | None = None,
        use_rest_semantics: bool | None = None,
    ):
        """Check system health

        get_server_status: Check the status of the database and file storage as well. When true, adds ``database_status`` and ``filestore_status`` to the response. If authenticated with ``manage_system`` permission, also adds ``root_status``.

        device_id: Check whether this device id can receive push notifications
        use_rest_semantics: Returns 200 status code even if the server status is unhealthy.

        `Read in Mattermost API docs (system - GetPing) <https://developers.mattermost.com/api-documentation/#/operations/GetPing>`_

        """
        __params = {
            "get_server_status": get_server_status,
            "device_id": device_id,
            "use_rest_semantics": use_rest_semantics,
        }
        return self.client.get("""/api/v4/system/ping""", params=__params)

    def get_notices(self, teamId: str, clientVersion: str, client: str, locale: str | None = None):
        """Get notices for logged in user in specified team

        teamId: ID of the team
        clientVersion: Version of the client (desktop/mobile/web) that issues the request
        locale: Client locale
        client: Client type (web/mobile-ios/mobile-android/desktop)

        `Read in Mattermost API docs (system - GetNotices) <https://developers.mattermost.com/api-documentation/#/operations/GetNotices>`_

        """
        __params = {"clientVersion": clientVersion, "locale": locale, "client": client}
        return self.client.get(f"/api/v4/system/notices/{teamId}", params=__params)

    def mark_notices_viewed(self, options: list[str]):
        """Update notices as 'viewed'
        `Read in Mattermost API docs (system - MarkNoticesViewed) <https://developers.mattermost.com/api-documentation/#/operations/MarkNoticesViewed>`_

        """
        return self.client.put("""/api/v4/system/notices/view""", options=options)

    def database_recycle(self):
        """Recycle database connections
        `Read in Mattermost API docs (system - DatabaseRecycle) <https://developers.mattermost.com/api-documentation/#/operations/DatabaseRecycle>`_

        """
        return self.client.post("""/api/v4/database/recycle""")

    def test_email(self, options: Any):
        """Send a test email
        `Read in Mattermost API docs (system - TestEmail) <https://developers.mattermost.com/api-documentation/#/operations/TestEmail>`_

        """
        return self.client.post("""/api/v4/email/test""", options=options)

    def test_notification(self):
        """Send a test notification
        `Read in Mattermost API docs (system - TestNotification) <https://developers.mattermost.com/api-documentation/#/operations/TestNotification>`_

        """
        return self.client.post("""/api/v4/notifications/test""")

    def test_site_url(self, site_url: str):
        """Checks the validity of a Site URL

        site_url: The Site URL to test

        `Read in Mattermost API docs (system - TestSiteURL) <https://developers.mattermost.com/api-documentation/#/operations/TestSiteURL>`_

        """
        __options = {"site_url": site_url}
        return self.client.post("""/api/v4/site_url/test""", options=__options)

    def test_s3_connection(self, options: Any):
        """Test AWS S3 connection
        `Read in Mattermost API docs (system - TestS3Connection) <https://developers.mattermost.com/api-documentation/#/operations/TestS3Connection>`_

        """
        return self.client.post("""/api/v4/file/s3_test""", options=options)

    def get_config(self, remove_masked: bool | None = False, remove_defaults: str | None = False):
        """Get configuration

        remove_masked: Remove masked values from the exported configuration.

        *Minimum server version*: 10.4.0

        remove_defaults: Remove default values from the exported configuration.

        *Minimum server version*: 10.4.0


        `Read in Mattermost API docs (system - GetConfig) <https://developers.mattermost.com/api-documentation/#/operations/GetConfig>`_

        """
        __params = {"remove_masked": remove_masked, "remove_defaults": remove_defaults}
        return self.client.get("""/api/v4/config""", params=__params)

    def update_config(self, options: Any):
        """Update configuration
        `Read in Mattermost API docs (system - UpdateConfig) <https://developers.mattermost.com/api-documentation/#/operations/UpdateConfig>`_

        """
        return self.client.put("""/api/v4/config""", options=options)

    def reload_config(self):
        """Reload configuration
        `Read in Mattermost API docs (system - ReloadConfig) <https://developers.mattermost.com/api-documentation/#/operations/ReloadConfig>`_

        """
        return self.client.post("""/api/v4/config/reload""")

    def get_client_config(self):
        """Get client configuration
        `Read in Mattermost API docs (system - GetClientConfig) <https://developers.mattermost.com/api-documentation/#/operations/GetClientConfig>`_

        """
        return self.client.get("""/api/v4/config/client""")

    def get_environment_config(self):
        """Get configuration made through environment variables
        `Read in Mattermost API docs (system - GetEnvironmentConfig) <https://developers.mattermost.com/api-documentation/#/operations/GetEnvironmentConfig>`_

        """
        return self.client.get("""/api/v4/config/environment""")

    def patch_config(self, options: Any):
        """Patch configuration
        `Read in Mattermost API docs (system - PatchConfig) <https://developers.mattermost.com/api-documentation/#/operations/PatchConfig>`_

        """
        return self.client.put("""/api/v4/config/patch""", options=options)

    def upload_license_file(self, license: BinaryIO):
        """Upload license file

        license: The license to be uploaded

        `Read in Mattermost API docs (system - UploadLicenseFile) <https://developers.mattermost.com/api-documentation/#/operations/UploadLicenseFile>`_

        """
        __files = {"license": license}
        return self.client.post("""/api/v4/license""", files=__files)

    def remove_license_file(self):
        """Remove license file
        `Read in Mattermost API docs (system - RemoveLicenseFile) <https://developers.mattermost.com/api-documentation/#/operations/RemoveLicenseFile>`_

        """
        return self.client.delete("""/api/v4/license""")

    def get_client_license(self, format: str):
        """Get client license

        format: Must be ``old``, other formats not implemented yet

        `Read in Mattermost API docs (system - GetClientLicense) <https://developers.mattermost.com/api-documentation/#/operations/GetClientLicense>`_

        """
        __params = {"format": format}
        return self.client.get("""/api/v4/license/client""", params=__params)

    def get_license_load_metric(self):
        """Get license load metric
        `Read in Mattermost API docs (system - GetLicenseLoadMetric) <https://developers.mattermost.com/api-documentation/#/operations/GetLicenseLoadMetric>`_

        """
        return self.client.get("""/api/v4/license/load_metric""")

    def request_license_renewal_link(self):
        """Request the license renewal link
        `Read in Mattermost API docs (system - RequestLicenseRenewalLink) <https://developers.mattermost.com/api-documentation/#/operations/RequestLicenseRenewalLink>`_

        """
        return self.client.get("""/api/v4/license/renewal""")

    def request_trial_license(self, users: int):
        """Request and install a trial license for your server

        users: Number of users requested (20% extra is going to be added)

        `Read in Mattermost API docs (system - RequestTrialLicense) <https://developers.mattermost.com/api-documentation/#/operations/RequestTrialLicense>`_

        """
        __options = {"users": users}
        return self.client.post("""/api/v4/trial-license""", options=__options)

    def get_prev_trial_license(self):
        """Get last trial license used
        `Read in Mattermost API docs (system - GetPrevTrialLicense) <https://developers.mattermost.com/api-documentation/#/operations/GetPrevTrialLicense>`_

        """
        return self.client.get("""/api/v4/trial-license/prev""")

    def get_audits(self, page: int | None = 0, per_page: int | None = 60):
        """Get audits

        page: The page to select.
        per_page: The number of audits per page.

        `Read in Mattermost API docs (system - GetAudits) <https://developers.mattermost.com/api-documentation/#/operations/GetAudits>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get("""/api/v4/audits""", params=__params)

    def invalidate_caches(self):
        """Invalidate all the caches
        `Read in Mattermost API docs (system - InvalidateCaches) <https://developers.mattermost.com/api-documentation/#/operations/InvalidateCaches>`_

        """
        return self.client.post("""/api/v4/caches/invalidate""")

    def get_logs(self, page: int | None = 0, logs_per_page: str | None = "10000"):
        """Get logs

        page: The page to select.
        logs_per_page: The number of logs per page. There is a maximum limit of 10000 logs per page.

        `Read in Mattermost API docs (system - GetLogs) <https://developers.mattermost.com/api-documentation/#/operations/GetLogs>`_

        """
        __params = {"page": page, "logs_per_page": logs_per_page}
        return self.client.get("""/api/v4/logs""", params=__params)

    def post_log(self, level: str, message: str):
        """Add log message

        level: The error level, ERROR or DEBUG
        message: Message to send to the server logs

        `Read in Mattermost API docs (system - PostLog) <https://developers.mattermost.com/api-documentation/#/operations/PostLog>`_

        """
        __options = {"level": level, "message": message}
        return self.client.post("""/api/v4/logs""", options=__options)

    def get_analytics_old(self, name: str | None = "standard", team_id: str | None = None):
        """Get analytics

        name: Possible values are "standard", "bot_post_counts_day", "post_counts_day", "user_counts_with_posts_day" or "extra_counts"
        team_id: The team ID to filter the data by

        `Read in Mattermost API docs (system - GetAnalyticsOld) <https://developers.mattermost.com/api-documentation/#/operations/GetAnalyticsOld>`_

        """
        __params = {"name": name, "team_id": team_id}
        return self.client.get("""/api/v4/analytics/old""", params=__params)

    def set_server_busy(self):
        """Set the server busy (high load) flag
        `Read in Mattermost API docs (system - SetServerBusy) <https://developers.mattermost.com/api-documentation/#/operations/SetServerBusy>`_

        """
        return self.client.post("""/api/v4/server_busy""")

    def get_server_busy_expires(self):
        """Get server busy expiry time.
        `Read in Mattermost API docs (system - GetServerBusyExpires) <https://developers.mattermost.com/api-documentation/#/operations/GetServerBusyExpires>`_

        """
        return self.client.get("""/api/v4/server_busy""")

    def clear_server_busy(self):
        """Clears the server busy (high load) flag
        `Read in Mattermost API docs (system - ClearServerBusy) <https://developers.mattermost.com/api-documentation/#/operations/ClearServerBusy>`_

        """
        return self.client.delete("""/api/v4/server_busy""")

    def get_redirect_location(self, url: str):
        """Get redirect location

        url: Url to check

        `Read in Mattermost API docs (system - GetRedirectLocation) <https://developers.mattermost.com/api-documentation/#/operations/GetRedirectLocation>`_

        """
        __params = {"url": url}
        return self.client.get("""/api/v4/redirect_location""", params=__params)

    def get_image_by_url(self):
        """Get an image by url
        `Read in Mattermost API docs (system - GetImageByUrl) <https://developers.mattermost.com/api-documentation/#/operations/GetImageByUrl>`_

        """
        return self.client.get("""/api/v4/image""")

    def upgrade_to_enterprise(self):
        """Executes an inplace upgrade from Team Edition to Enterprise Edition
        `Read in Mattermost API docs (system - UpgradeToEnterprise) <https://developers.mattermost.com/api-documentation/#/operations/UpgradeToEnterprise>`_

        """
        return self.client.post("""/api/v4/upgrade_to_enterprise""")

    def upgrade_to_enterprise_status(self):
        """Get the current status for the inplace upgrade from Team Edition to Enterprise Edition
        `Read in Mattermost API docs (system - UpgradeToEnterpriseStatus) <https://developers.mattermost.com/api-documentation/#/operations/UpgradeToEnterpriseStatus>`_

        """
        return self.client.get("""/api/v4/upgrade_to_enterprise/status""")

    def is_allowed_to_upgrade_to_enterprise(self):
        """Check if the user is allowed to upgrade to Enterprise Edition
        `Read in Mattermost API docs (system - IsAllowedToUpgradeToEnterprise) <https://developers.mattermost.com/api-documentation/#/operations/IsAllowedToUpgradeToEnterprise>`_

        """
        return self.client.get("""/api/v4/upgrade_to_enterprise/allowed""")

    def restart_server(self):
        """Restart the system after an upgrade from Team Edition to Enterprise Edition
        `Read in Mattermost API docs (system - RestartServer) <https://developers.mattermost.com/api-documentation/#/operations/RestartServer>`_

        """
        return self.client.post("""/api/v4/restart""")

    def check_integrity(self):
        """Perform a database integrity check
        `Read in Mattermost API docs (system - CheckIntegrity) <https://developers.mattermost.com/api-documentation/#/operations/CheckIntegrity>`_

        """
        return self.client.post("""/api/v4/integrity""")

    def generate_support_packet(self, basic_server_logs: bool | None = None, plugin_packets: str | None = None):
        """Download a zip file which contains helpful and useful information for troubleshooting your mattermost instance.

        basic_server_logs: Specifies whether the server should include or exclude log files. Default value is true.

        *Minimum server version*: 9.8.0

        plugin_packets: Specifies plugin identifiers whose content should be included in the Support Packet.

        *Minimum server version*: 9.8.0


        `Read in Mattermost API docs (system - GenerateSupportPacket) <https://developers.mattermost.com/api-documentation/#/operations/GenerateSupportPacket>`_

        """
        __params = {"basic_server_logs": basic_server_logs, "plugin_packets": plugin_packets}
        return self.client.get("""/api/v4/system/support_packet""", params=__params)

    def update_marketplace_visited_by_admin(self, options: Any):
        """Stores that the Plugin Marketplace has been visited by at least an admin.
        `Read in Mattermost API docs (system - UpdateMarketplaceVisitedByAdmin) <https://developers.mattermost.com/api-documentation/#/operations/UpdateMarketplaceVisitedByAdmin>`_

        """
        return self.client.post("""/api/v4/plugins/marketplace/first_admin_visit""", options=options)



from ._base import Base
from typing import Any, BinaryIO

__all__ = ["Search"]


class Search(Base):

    def search_files(
        self,
        team_id: str,
        terms: str,
        is_or_search: bool,
        time_zone_offset: int | None = 0,
        include_deleted_channels: bool | None = None,
        page: int | None = 0,
        per_page: int | None = 60,
    ):
        """Search files in a team

        team_id: Team GUID
        terms: The search terms as inputed by the user. To search for files from a user include ``from:someusername``, using a user's username. To search in a specific channel include ``in:somechannel``, using the channel name (not the display name). To search for specific extensions include ``ext:extension``.
        is_or_search: Set to true if an Or search should be performed vs an And search.
        time_zone_offset: Offset from UTC of user timezone for date searches.
        include_deleted_channels: Set to true if deleted channels should be included in the search. (archived channels)
        page: The page to select. (Only works with Elasticsearch)
        per_page: The number of posts per page. (Only works with Elasticsearch)

        `Read in Mattermost API docs (search - SearchFiles) <https://developers.mattermost.com/api-documentation/#/operations/SearchFiles>`_

        """
        __data = {
            "terms": terms,
            "is_or_search": is_or_search,
            "time_zone_offset": time_zone_offset,
            "include_deleted_channels": include_deleted_channels,
            "page": page,
            "per_page": per_page,
        }
        return self.client.post(f"/api/v4/teams/{team_id}/files/search", data=__data)

    def search_files(
        self,
        terms: str,
        is_or_search: bool,
        time_zone_offset: int | None = 0,
        include_deleted_channels: bool | None = None,
        page: int | None = 0,
        per_page: int | None = 60,
    ):
        """Search files across the teams of the current user

        terms: The search terms as entered by the user. To search for files from a user include ``from:someusername``, using a user's username. To search in a specific channel include ``in:somechannel``, using the channel name (not the display name). To search for specific extensions include ``ext:extension``.
        is_or_search: Set to true if an Or search should be performed vs an And search.
        time_zone_offset: Offset from UTC of user timezone for date searches.
        include_deleted_channels: Set to true if deleted channels should be included in the search. (archived channels)
        page: The page to select. (Only works with Elasticsearch)
        per_page: The number of posts per page. (Only works with Elasticsearch)

        `Read in Mattermost API docs (search - SearchFiles) <https://developers.mattermost.com/api-documentation/#/operations/SearchFiles>`_

        """
        __data = {
            "terms": terms,
            "is_or_search": is_or_search,
            "time_zone_offset": time_zone_offset,
            "include_deleted_channels": include_deleted_channels,
            "page": page,
            "per_page": per_page,
        }
        return self.client.post("""/api/v4/files/search""", data=__data)



from ._base import Base
from typing import Any, BinaryIO

__all__ = ["Bleve"]


class Bleve(Base):

    def purge_bleve_indexes(self):
        """Purge all Bleve indexes
        `Read in Mattermost API docs (bleve - PurgeBleveIndexes) <https://developers.mattermost.com/api-documentation/#/operations/PurgeBleveIndexes>`_

        """
        return self.client.post("""/api/v4/bleve/purge_indexes""")



from ._base import Base

__all__ = ["Agents"]


class Agents(Base):

    def get_agents(self):
        """Get available agents
        `Read in Mattermost API docs (agents - GetAgents) <https://developers.mattermost.com/api-documentation/#/operations/GetAgents>`_

        """
        return self.client.get("""/api/v4/agents""")

    def get_llm_services(self):
        """Get available LLM services
        `Read in Mattermost API docs (agents - GetLLMServices) <https://developers.mattermost.com/api-documentation/#/operations/GetLLMServices>`_

        """
        return self.client.get("""/api/v4/llmservices""")



from ._base import Base

__all__ = ["Imports"]


class Imports(Base):

    def list_imports(self):
        """List import files
        `Read in Mattermost API docs (imports - ListImports) <https://developers.mattermost.com/api-documentation/#/operations/ListImports>`_

        """
        return self.client.get("""/api/v4/imports""")

    def delete_import(self, import_name):
        """Delete an import file

        import_name: The name of the import file to delete

        `Read in Mattermost API docs (imports - DeleteImport) <https://developers.mattermost.com/api-documentation/#/operations/DeleteImport>`_

        """
        return self.client.delete(f"/api/v4/imports/{import_name}")



from ._base import Base

__all__ = ["Bookmarks"]


class Bookmarks(Base):

    def list_channel_bookmarks_for_channel(self, channel_id, params=None):
        """Get channel bookmarks for Channel

        channel_id: Channel GUID
        bookmarks_since: Timestamp to filter the bookmarks with. If set, the
        endpoint returns bookmarks that have been added, updated
        or deleted since its value


        `Read in Mattermost API docs (bookmarks - ListChannelBookmarksForChannel) <https://developers.mattermost.com/api-documentation/#/operations/ListChannelBookmarksForChannel>`_

        """
        return self.client.get(f"/api/v4/channels/{channel_id}/bookmarks", params=params)

    def create_channel_bookmark(self, channel_id, options):
        """Create channel bookmark

        channel_id: Channel GUID
        file_id: The ID of the file associated with the channel bookmark. Required for bookmarks of type 'file'
        display_name: The name of the channel bookmark
        link_url: The URL associated with the channel bookmark. Required for bookmarks of type 'link'
        image_url: The URL of the image associated with the channel bookmark. Optional, only applies for bookmarks of type 'link'
        emoji: The emoji of the channel bookmark
        type: * ``link`` for channel bookmarks that reference a link. ``link_url`` is requied
        * ``file`` for channel bookmarks that reference a file. ``file_id`` is required


        `Read in Mattermost API docs (bookmarks - CreateChannelBookmark) <https://developers.mattermost.com/api-documentation/#/operations/CreateChannelBookmark>`_

        """
        return self.client.post(f"/api/v4/channels/{channel_id}/bookmarks", options=options)

    def update_channel_bookmark(self, channel_id, bookmark_id, options):
        """Update channel bookmark

        channel_id: Channel GUID
        bookmark_id: Bookmark GUID
        file_id: The ID of the file associated with the channel bookmark. Required for bookmarks of type 'file'
        display_name: The name of the channel bookmark
        sort_order: The order of the channel bookmark
        link_url: The URL associated with the channel bookmark. Required for type bookmarks of type 'link'
        image_url: The URL of the image associated with the channel bookmark
        emoji: The emoji of the channel bookmark
        type: * ``link`` for channel bookmarks that reference a link. ``link_url`` is requied
        * ``file`` for channel bookmarks that reference a file. ``file_id`` is required


        `Read in Mattermost API docs (bookmarks - UpdateChannelBookmark) <https://developers.mattermost.com/api-documentation/#/operations/UpdateChannelBookmark>`_

        """
        return self.client.patch(f"/api/v4/channels/{channel_id}/bookmarks/{bookmark_id}", options=options)

    def delete_channel_bookmark(self, channel_id, bookmark_id):
        """Delete channel bookmark

        channel_id: Channel GUID
        bookmark_id: Bookmark GUID

        `Read in Mattermost API docs (bookmarks - DeleteChannelBookmark) <https://developers.mattermost.com/api-documentation/#/operations/DeleteChannelBookmark>`_

        """
        return self.client.delete(f"/api/v4/channels/{channel_id}/bookmarks/{bookmark_id}")

    def update_channel_bookmark_sort_order(self, channel_id, bookmark_id, options=None):
        """Update channel bookmark's order

        channel_id: Channel GUID
        bookmark_id: Bookmark GUID

        `Read in Mattermost API docs (bookmarks - UpdateChannelBookmarkSortOrder) <https://developers.mattermost.com/api-documentation/#/operations/UpdateChannelBookmarkSortOrder>`_

        """
        return self.client.post(f"/api/v4/channels/{channel_id}/bookmarks/{bookmark_id}/sort_order", options=options)



from ._base import Base
from typing import Any, BinaryIO

__all__ = ["Conditions"]


class Conditions(Base):

    def get_playbook_conditions(self, id: str, page: int | None = 0, per_page: int | None = 20):
        """List playbook conditions

        id: ID of the playbook to retrieve conditions from.
        page: Zero-based index of the page to request.
        per_page: Number of conditions to return per page.

        `Read in Mattermost API docs (conditions - getPlaybookConditions) <https://developers.mattermost.com/api-documentation/#/operations/getPlaybookConditions>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get(f"/plugins/playbooks/api/v0/playbooks/{id}/conditions", params=__params)

    def create_playbook_condition(self, id: str, options: Any | None = None):
        """Create a playbook condition

        id: ID of the playbook to create a condition for.

        `Read in Mattermost API docs (conditions - createPlaybookCondition) <https://developers.mattermost.com/api-documentation/#/operations/createPlaybookCondition>`_

        """
        return self.client.post(f"/plugins/playbooks/api/v0/playbooks/{id}/conditions", options=options)

    def update_playbook_condition(self, id: str, conditionID: str, options: Any | None = None):
        """Update a playbook condition

        id: ID of the playbook.
        conditionID: ID of the condition to update.

        `Read in Mattermost API docs (conditions - updatePlaybookCondition) <https://developers.mattermost.com/api-documentation/#/operations/updatePlaybookCondition>`_

        """
        return self.client.put(f"/plugins/playbooks/api/v0/playbooks/{id}/conditions/{conditionID}", options=options)

    def delete_playbook_condition(self, id: str, conditionID: str):
        """Delete a playbook condition

        id: ID of the playbook.
        conditionID: ID of the condition to delete.

        `Read in Mattermost API docs (conditions - deletePlaybookCondition) <https://developers.mattermost.com/api-documentation/#/operations/deletePlaybookCondition>`_

        """
        return self.client.delete(f"/plugins/playbooks/api/v0/playbooks/{id}/conditions/{conditionID}")

    def get_run_conditions(self, id: str, page: int | None = 0, per_page: int | None = 20):
        """List run conditions

        id: ID of the run to retrieve conditions from.
        page: Zero-based index of the page to request.
        per_page: Number of conditions to return per page.

        `Read in Mattermost API docs (conditions - getRunConditions) <https://developers.mattermost.com/api-documentation/#/operations/getRunConditions>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get(f"/plugins/playbooks/api/v0/runs/{id}/conditions", params=__params)



from ._base import Base
from typing import Any, BinaryIO

__all__ = ["SharedChannels"]


class SharedChannels(Base):

    def get_shared_channel_remotes(self, channel_id: str):
        """Get remote clusters for a shared channel

        channel_id: Channel GUID

        `Read in Mattermost API docs (shared_channels - GetSharedChannelRemotes) <https://developers.mattermost.com/api-documentation/#/operations/GetSharedChannelRemotes>`_

        """
        return self.client.get(f"/api/v4/sharedchannels/{channel_id}/remotes")

    def get_all_shared_channels(self, team_id: str, page: int | None = 0, per_page: int | None = 0):
        """Get all shared channels for team.

        team_id: Team Id
        page: The page to select.
        per_page: The number of sharedchannels per page.

        `Read in Mattermost API docs (shared_channels - GetAllSharedChannels) <https://developers.mattermost.com/api-documentation/#/operations/GetAllSharedChannels>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get(f"/api/v4/sharedchannels/{team_id}", params=__params)

    def get_shared_channel_remotes_by_remote_cluster(
        self,
        remote_id: str,
        include_unconfirmed: bool | None = None,
        exclude_confirmed: bool | None = None,
        exclude_home: bool | None = None,
        exclude_remote: bool | None = None,
        include_deleted: bool | None = None,
        page: int | None = None,
        per_page: int | None = None,
    ):
        """Get shared channel remotes by remote cluster.

        remote_id: The remote cluster GUID
        include_unconfirmed: Include those Shared channel remotes that are unconfirmed
        exclude_confirmed: Show only those Shared channel remotes that are not confirmed yet
        exclude_home: Show only those Shared channel remotes that were shared with this server
        exclude_remote: Show only those Shared channel remotes that were shared from this server
        include_deleted: Include those Shared channel remotes that have been deleted
        page: The page to select
        per_page: The number of shared channels per page

        `Read in Mattermost API docs (shared_channels - GetSharedChannelRemotesByRemoteCluster) <https://developers.mattermost.com/api-documentation/#/operations/GetSharedChannelRemotesByRemoteCluster>`_

        """
        __params = {
            "include_unconfirmed": include_unconfirmed,
            "exclude_confirmed": exclude_confirmed,
            "exclude_home": exclude_home,
            "exclude_remote": exclude_remote,
            "include_deleted": include_deleted,
            "page": page,
            "per_page": per_page,
        }
        return self.client.get(f"/api/v4/remotecluster/{remote_id}/sharedchannelremotes", params=__params)

    def get_remote_cluster_info(self, remote_id: str):
        """Get remote cluster info by ID for user.

        remote_id: Remote Cluster GUID

        `Read in Mattermost API docs (shared_channels - GetRemoteClusterInfo) <https://developers.mattermost.com/api-documentation/#/operations/GetRemoteClusterInfo>`_

        """
        return self.client.get(f"/api/v4/sharedchannels/remote_info/{remote_id}")

    def invite_remote_cluster_to_channel(self, remote_id: str, channel_id: str):
        """Invites a remote cluster to a channel.

        remote_id: The remote cluster GUID
        channel_id: The channel GUID to invite the remote cluster to

        `Read in Mattermost API docs (shared_channels - InviteRemoteClusterToChannel) <https://developers.mattermost.com/api-documentation/#/operations/InviteRemoteClusterToChannel>`_

        """
        return self.client.post(f"/api/v4/remotecluster/{remote_id}/channels/{channel_id}/invite")

    def uninvite_remote_cluster_to_channel(self, remote_id: str, channel_id: str):
        """Uninvites a remote cluster to a channel.

        remote_id: The remote cluster GUID
        channel_id: The channel GUID to uninvite the remote cluster to

        `Read in Mattermost API docs (shared_channels - UninviteRemoteClusterToChannel) <https://developers.mattermost.com/api-documentation/#/operations/UninviteRemoteClusterToChannel>`_

        """
        return self.client.post(f"/api/v4/remotecluster/{remote_id}/channels/{channel_id}/uninvite")

    def can_user_direct_message(self, user_id: str, other_user_id: str):
        """Check if user can DM another user in shared channels context

        user_id: User GUID
        other_user_id: Other user GUID

        `Read in Mattermost API docs (shared_channels - CanUserDirectMessage) <https://developers.mattermost.com/api-documentation/#/operations/CanUserDirectMessage>`_

        """
        return self.client.get(f"/api/v4/sharedchannels/users/{user_id}/can_dm/{other_user_id}")



from ._base import Base

__all__ = ["Migrate"]


class Migrate(Base):

    def migrate_auth_to_ldap(self, options=None):
        """Migrate user accounts authentication type to LDAP.

        from: The current authentication type for the matched users.
        match_field: Foreign user field name to match.
        force:

        `Read in Mattermost API docs (migrate - MigrateAuthToLdap) <https://developers.mattermost.com/api-documentation/#/operations/MigrateAuthToLdap>`_

        """
        return self.client.post("""/api/v4/users/migrate_auth/ldap""", options=options)

    def migrate_auth_to_saml(self, options=None):
        """Migrate user accounts authentication type to SAML.

        from: The current authentication type for the matched users.
        matches: Users map.
        auto:

        `Read in Mattermost API docs (migrate - MigrateAuthToSaml) <https://developers.mattermost.com/api-documentation/#/operations/MigrateAuthToSaml>`_

        """
        return self.client.post("""/api/v4/users/migrate_auth/saml""", options=options)



from ._base import Base

__all__ = ["OAuth"]


class OAuth(Base):

    def create_o_auth_app(self, options):
        """Register OAuth app

        name: The name of the client application
        description: A short description of the application
        icon_url: A URL to an icon to display with the application
        callback_urls: A list of callback URLs for the appliation
        homepage: A link to the website of the application
        is_trusted: Set this to ``true`` to skip asking users for permission
        is_public: Set this to ``true`` to create a public client (no client secret). Public clients must use PKCE for authorization.

        `Read in Mattermost API docs (o_auth - CreateOAuthApp) <https://developers.mattermost.com/api-documentation/#/operations/CreateOAuthApp>`_

        """
        return self.client.post("""/api/v4/oauth/apps""", options=options)

    def get_o_auth_apps(self, params=None):
        """Get OAuth apps

        page: The page to select.
        per_page: The number of apps per page.

        `Read in Mattermost API docs (o_auth - GetOAuthApps) <https://developers.mattermost.com/api-documentation/#/operations/GetOAuthApps>`_

        """
        return self.client.get("""/api/v4/oauth/apps""", params=params)

    def get_o_auth_app(self, app_id):
        """Get an OAuth app

        app_id: Application client id

        `Read in Mattermost API docs (o_auth - GetOAuthApp) <https://developers.mattermost.com/api-documentation/#/operations/GetOAuthApp>`_

        """
        return self.client.get(f"/api/v4/oauth/apps/{app_id}")

    def update_o_auth_app(self, app_id, options):
        """Update an OAuth app

        app_id: Application client id
        id: The id of the client application
        name: The name of the client application
        description: A short description of the application
        icon_url: A URL to an icon to display with the application
        callback_urls: A list of callback URLs for the appliation
        homepage: A link to the website of the application
        is_trusted: Set this to ``true`` to skip asking users for permission. It will be set to false if value is not provided.

        `Read in Mattermost API docs (o_auth - UpdateOAuthApp) <https://developers.mattermost.com/api-documentation/#/operations/UpdateOAuthApp>`_

        """
        return self.client.put(f"/api/v4/oauth/apps/{app_id}", options=options)

    def delete_o_auth_app(self, app_id):
        """Delete an OAuth app

        app_id: Application client id

        `Read in Mattermost API docs (o_auth - DeleteOAuthApp) <https://developers.mattermost.com/api-documentation/#/operations/DeleteOAuthApp>`_

        """
        return self.client.delete(f"/api/v4/oauth/apps/{app_id}")

    def regenerate_o_auth_app_secret(self, app_id):
        """Regenerate OAuth app secret

        app_id: Application client id

        `Read in Mattermost API docs (o_auth - RegenerateOAuthAppSecret) <https://developers.mattermost.com/api-documentation/#/operations/RegenerateOAuthAppSecret>`_

        """
        return self.client.post(f"/api/v4/oauth/apps/{app_id}/regen_secret")

    def get_o_auth_app_info(self, app_id):
        """Get info on an OAuth app

        app_id: Application client id

        `Read in Mattermost API docs (o_auth - GetOAuthAppInfo) <https://developers.mattermost.com/api-documentation/#/operations/GetOAuthAppInfo>`_

        """
        return self.client.get(f"/api/v4/oauth/apps/{app_id}/info")

    def get_authorization_server_metadata(self):
        """Get OAuth 2.0 Authorization Server Metadata
        `Read in Mattermost API docs (o_auth - GetAuthorizationServerMetadata) <https://developers.mattermost.com/api-documentation/#/operations/GetAuthorizationServerMetadata>`_

        """
        return self.client.get("""/.well-known/oauth-authorization-server""")

    def register_o_auth_client(self, options):
        """Register OAuth client using Dynamic Client Registration
        `Read in Mattermost API docs (o_auth - RegisterOAuthClient) <https://developers.mattermost.com/api-documentation/#/operations/RegisterOAuthClient>`_

        """
        return self.client.post("""/api/v4/oauth/apps/register""", options=options)

    def get_authorized_o_auth_apps_for_user(self, user_id, params=None):
        """Get authorized OAuth apps

        user_id: User GUID
        page: The page to select.
        per_page: The number of apps per page.

        `Read in Mattermost API docs (o_auth - GetAuthorizedOAuthAppsForUser) <https://developers.mattermost.com/api-documentation/#/operations/GetAuthorizedOAuthAppsForUser>`_

        """
        return self.client.get(f"/api/v4/users/{user_id}/oauth/apps/authorized", params=params)



from ._base import Base

__all__ = ["IntegrationActions"]


class IntegrationActions(Base):

    def open_interactive_dialog(self, options):
        """Open a dialog

        trigger_id: Trigger ID provided by other action
        url: The URL to send the submitted dialog payload to
        dialog: Post object to create

        `Read in Mattermost API docs (integration_actions - OpenInteractiveDialog) <https://developers.mattermost.com/api-documentation/#/operations/OpenInteractiveDialog>`_

        """
        return self.client.post("""/api/v4/actions/dialogs/open""", options=options)

    def submit_interactive_dialog(self, options):
        """Submit a dialog

        url: The URL to send the submitted dialog payload to
        channel_id: Channel ID the user submitted the dialog from
        team_id: Team ID the user submitted the dialog from
        submission: String map where keys are element names and values are the element input values
        callback_id: Callback ID sent when the dialog was opened
        state: State sent when the dialog was opened
        cancelled: Set to true if the dialog was cancelled

        `Read in Mattermost API docs (integration_actions - SubmitInteractiveDialog) <https://developers.mattermost.com/api-documentation/#/operations/SubmitInteractiveDialog>`_

        """
        return self.client.post("""/api/v4/actions/dialogs/submit""", options=options)

    def lookup_interactive_dialog(self, options):
        """Lookup dialog elements

        url: The URL to send the lookup request to
        channel_id: Channel ID the user is performing the lookup from
        team_id: Team ID the user is performing the lookup from
        submission: String map where keys are element names and values are the element input values
        callback_id: Callback ID sent when the dialog was opened
        state: State sent when the dialog was opened

        `Read in Mattermost API docs (integration_actions - LookupInteractiveDialog) <https://developers.mattermost.com/api-documentation/#/operations/LookupInteractiveDialog>`_

        """
        return self.client.post("""/api/v4/actions/dialogs/lookup""", options=options)



from ._base import Base
from typing import Any, BinaryIO

__all__ = ["Schemes"]


class Schemes(Base):

    def get_schemes(self, scope: str | None = "", page: int | None = 0, per_page: int | None = 60):
        """Get the schemes.

        scope: Limit the results returned to the provided scope, either ``team`` or ``channel``.
        page: The page to select.
        per_page: The number of schemes per page.

        `Read in Mattermost API docs (schemes - GetSchemes) <https://developers.mattermost.com/api-documentation/#/operations/GetSchemes>`_

        """
        __params = {"scope": scope, "page": page, "per_page": per_page}
        return self.client.get("""/api/v4/schemes""", params=__params)

    def create_scheme(self, display_name: str, scope: str, name: str | None = None, description: str | None = None):
        """Create a scheme

        name: The name of the scheme
        display_name: The display name of the scheme
        description: The description of the scheme
        scope: The scope of the scheme ("team" or "channel")

        `Read in Mattermost API docs (schemes - CreateScheme) <https://developers.mattermost.com/api-documentation/#/operations/CreateScheme>`_

        """
        __options = {"name": name, "display_name": display_name, "description": description, "scope": scope}
        return self.client.post("""/api/v4/schemes""", options=__options)

    def get_scheme(self, scheme_id: str):
        """Get a scheme

        scheme_id: Scheme GUID

        `Read in Mattermost API docs (schemes - GetScheme) <https://developers.mattermost.com/api-documentation/#/operations/GetScheme>`_

        """
        return self.client.get(f"/api/v4/schemes/{scheme_id}")

    def delete_scheme(self, scheme_id: str):
        """Delete a scheme

        scheme_id: ID of the scheme to delete

        `Read in Mattermost API docs (schemes - DeleteScheme) <https://developers.mattermost.com/api-documentation/#/operations/DeleteScheme>`_

        """
        return self.client.delete(f"/api/v4/schemes/{scheme_id}")

    def patch_scheme(self, scheme_id: str, name: str | None = None, description: str | None = None):
        """Patch a scheme

        scheme_id: Scheme GUID
        name: The human readable name of the scheme
        description: The description of the scheme

        `Read in Mattermost API docs (schemes - PatchScheme) <https://developers.mattermost.com/api-documentation/#/operations/PatchScheme>`_

        """
        __options = {"name": name, "description": description}
        return self.client.put(f"/api/v4/schemes/{scheme_id}/patch", options=__options)

    def get_teams_for_scheme(self, scheme_id: str, page: int | None = 0, per_page: int | None = 60):
        """Get a page of teams which use this scheme.

        scheme_id: Scheme GUID
        page: The page to select.
        per_page: The number of teams per page.

        `Read in Mattermost API docs (schemes - GetTeamsForScheme) <https://developers.mattermost.com/api-documentation/#/operations/GetTeamsForScheme>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get(f"/api/v4/schemes/{scheme_id}/teams", params=__params)

    def get_channels_for_scheme(self, scheme_id: str, page: int | None = 0, per_page: int | None = 60):
        """Get a page of channels which use this scheme.

        scheme_id: Scheme GUID
        page: The page to select.
        per_page: The number of channels per page.

        `Read in Mattermost API docs (schemes - GetChannelsForScheme) <https://developers.mattermost.com/api-documentation/#/operations/GetChannelsForScheme>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get(f"/api/v4/schemes/{scheme_id}/channels", params=__params)



from ._base import Base
from typing import Any, BinaryIO

__all__ = ["Jobs"]


class Jobs(Base):

    def get_jobs(
        self, page: int | None = 0, per_page: int | None = 5, job_type: str | None = None, status: str | None = None
    ):
        """Get the jobs.

        page: The page to select.
        per_page: The number of jobs per page.
        job_type: The type of jobs to fetch.
        status: The status of jobs to fetch.

        `Read in Mattermost API docs (jobs - GetJobs) <https://developers.mattermost.com/api-documentation/#/operations/GetJobs>`_

        """
        __params = {"page": page, "per_page": per_page, "job_type": job_type, "status": status}
        return self.client.get("""/api/v4/jobs""", params=__params)

    def create_job(self, type: str, data: dict[str, Any] | None = None):
        """Create a new job.

        type: The type of job to create
        data: An object containing any additional data required for this job type

        `Read in Mattermost API docs (jobs - CreateJob) <https://developers.mattermost.com/api-documentation/#/operations/CreateJob>`_

        """
        __options = {"type": type, "data": data}
        return self.client.post("""/api/v4/jobs""", options=__options)

    def get_job(self, job_id: str):
        """Get a job.

        job_id: Job GUID

        `Read in Mattermost API docs (jobs - GetJob) <https://developers.mattermost.com/api-documentation/#/operations/GetJob>`_

        """
        return self.client.get(f"/api/v4/jobs/{job_id}")

    def download_job(self, job_id: str):
        """Download the results of a job.

        job_id: Job GUID

        `Read in Mattermost API docs (jobs - DownloadJob) <https://developers.mattermost.com/api-documentation/#/operations/DownloadJob>`_

        """
        return self.client.get(f"/api/v4/jobs/{job_id}/download")

    def cancel_job(self, job_id: str):
        """Cancel a job.

        job_id: Job GUID

        `Read in Mattermost API docs (jobs - CancelJob) <https://developers.mattermost.com/api-documentation/#/operations/CancelJob>`_

        """
        return self.client.post(f"/api/v4/jobs/{job_id}/cancel")

    def get_jobs_by_type(self, type: str, page: int | None = 0, per_page: int | None = 60):
        """Get the jobs of the given type.

        type: Job type
        page: The page to select.
        per_page: The number of jobs per page.

        `Read in Mattermost API docs (jobs - GetJobsByType) <https://developers.mattermost.com/api-documentation/#/operations/GetJobsByType>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get(f"/api/v4/jobs/type/{type}", params=__params)

    def update_job_status(self, job_id: str, status: str, force: bool | None = None):
        """Update the status of a job

        job_id: Job GUID
        status: The status you want to set
        force: Set this to true to bypass status restrictions

        `Read in Mattermost API docs (jobs - UpdateJobStatus) <https://developers.mattermost.com/api-documentation/#/operations/UpdateJobStatus>`_

        """
        __options = {"status": status, "force": force}
        return self.client.patch(f"/api/v4/jobs/{job_id}/status", options=__options)



from ._base import Base
from typing import Any, BinaryIO

__all__ = ["Channels"]


class Channels(Base):

    def get_all_channels(
        self,
        not_associated_to_group: str | None = None,
        page: int | None = 0,
        per_page: int | None = 0,
        exclude_default_channels: bool | None = False,
        include_deleted: bool | None = False,
        include_total_count: bool | None = False,
        exclude_policy_constrained: bool | None = False,
    ):
        """Get a list of all channels

        not_associated_to_group: A group id to exclude channels that are associated with that group via GroupChannel records. This can also be left blank with ``not_associated_to_group=``.
        page: The page to select.
        per_page: The number of channels per page.
        exclude_default_channels: Whether to exclude default channels (ex Town Square, Off-Topic) from the results.
        include_deleted: Include channels that have been archived. This correlates to the ``DeleteAt`` flag being set in the database.
        include_total_count: Appends a total count of returned channels inside the response object - ex: ``{ "channels": [], "total_count" : 0 }``.
        exclude_policy_constrained: If set to true, channels which are part of a data retention policy will be excluded. The ``sysconsole_read_compliance`` permission is required to use this parameter.
        *Minimum server version*: 5.35

        `Read in Mattermost API docs (channels - GetAllChannels) <https://developers.mattermost.com/api-documentation/#/operations/GetAllChannels>`_

        """
        __params = {
            "not_associated_to_group": not_associated_to_group,
            "page": page,
            "per_page": per_page,
            "exclude_default_channels": exclude_default_channels,
            "include_deleted": include_deleted,
            "include_total_count": include_total_count,
            "exclude_policy_constrained": exclude_policy_constrained,
        }
        return self.client.get("""/api/v4/channels""", params=__params)

    def create_channel(
        self,
        team_id: str,
        name: str,
        display_name: str,
        type: str,
        purpose: str | None = None,
        header: str | None = None,
    ):
        """Create a channel

        team_id: The team ID of the team to create the channel on
        name: The unique handle for the channel, will be present in the channel URL
        display_name: The non-unique UI name for the channel
        purpose: A short description of the purpose of the channel
        header: Markdown-formatted text to display in the header of the channel
        type: 'O' for a public channel, 'P' for a private channel

        `Read in Mattermost API docs (channels - CreateChannel) <https://developers.mattermost.com/api-documentation/#/operations/CreateChannel>`_

        """
        __options = {
            "team_id": team_id,
            "name": name,
            "display_name": display_name,
            "purpose": purpose,
            "header": header,
            "type": type,
        }
        return self.client.post("""/api/v4/channels""", options=__options)

    def create_direct_channel(self, options: list[str]):
        """Create a direct message channel
        `Read in Mattermost API docs (channels - CreateDirectChannel) <https://developers.mattermost.com/api-documentation/#/operations/CreateDirectChannel>`_

        """
        return self.client.post("""/api/v4/channels/direct""", options=options)

    def create_group_channel(self, options: list[str]):
        """Create a group message channel
        `Read in Mattermost API docs (channels - CreateGroupChannel) <https://developers.mattermost.com/api-documentation/#/operations/CreateGroupChannel>`_

        """
        return self.client.post("""/api/v4/channels/group""", options=options)

    def search_all_channels(
        self,
        term: str,
        not_associated_to_group: str | None = None,
        exclude_default_channels: bool | None = None,
        team_ids: list[str] | None = None,
        group_constrained: bool | None = None,
        exclude_group_constrained: bool | None = None,
        public: bool | None = None,
        private: bool | None = None,
        deleted: bool | None = None,
        page: str | None = None,
        per_page: str | None = None,
        exclude_policy_constrained: bool | None = False,
        include_search_by_id: bool | None = False,
        exclude_remote: bool | None = False,
    ):
        """Search all private and open type channels across all teams

        term: The string to search in the channel name, display name, and purpose.
        not_associated_to_group: A group id to exclude channels that are associated to that group via GroupChannel records.
        exclude_default_channels: Exclude default channels from the results by setting this parameter to true.
        team_ids: Filters results to channels belonging to the given team ids

        *Minimum server version*: 5.26

        group_constrained: Filters results to only return channels constrained to a group

        *Minimum server version*: 5.26

        exclude_group_constrained: Filters results to exclude channels constrained to a group

        *Minimum server version*: 5.26

        public: Filters results to only return Public / Open channels, can be used in conjunction with ``private`` to return both ``public`` and ``private`` channels

        *Minimum server version*: 5.26

        private: Filters results to only return Private channels, can be used in conjunction with ``public`` to return both ``private`` and ``public`` channels

        *Minimum server version*: 5.26

        deleted: Filters results to only return deleted / archived channels

        *Minimum server version*: 5.26

        page: The page number to return, if paginated. If this parameter is not present with the ``per_page`` parameter then the results will be returned un-paged.
        per_page: The number of entries to return per page, if paginated. If this parameter is not present with the ``page`` parameter then the results will be returned un-paged.
        exclude_policy_constrained: If set to true, only channels which do not have a granular retention policy assigned to them will be returned. The ``sysconsole_read_compliance_data_retention`` permission is required to use this parameter.
        *Minimum server version*: 5.35

        include_search_by_id: If set to true, returns channels where given search 'term' matches channel ID.
        *Minimum server version*: 5.35

        exclude_remote: If set to true, only returns channels that are local to this server.
        *Minimum server version*: 10.2


        `Read in Mattermost API docs (channels - SearchAllChannels) <https://developers.mattermost.com/api-documentation/#/operations/SearchAllChannels>`_

        """
        __options = {
            "term": term,
            "not_associated_to_group": not_associated_to_group,
            "exclude_default_channels": exclude_default_channels,
            "team_ids": team_ids,
            "group_constrained": group_constrained,
            "exclude_group_constrained": exclude_group_constrained,
            "public": public,
            "private": private,
            "deleted": deleted,
            "page": page,
            "per_page": per_page,
            "exclude_policy_constrained": exclude_policy_constrained,
            "include_search_by_id": include_search_by_id,
            "exclude_remote": exclude_remote,
        }
        return self.client.post("""/api/v4/channels/search""", options=__options)

    def search_group_channels(self, term: str):
        """Search Group Channels

        term: The search term to match against the members' usernames of the group channels

        `Read in Mattermost API docs (channels - SearchGroupChannels) <https://developers.mattermost.com/api-documentation/#/operations/SearchGroupChannels>`_

        """
        __options = {"term": term}
        return self.client.post("""/api/v4/channels/group/search""", options=__options)

    def get_public_channels_by_ids_for_team(self, team_id: str, options: list[str]):
        """Get a list of channels by ids

        team_id: Team GUID

        `Read in Mattermost API docs (channels - GetPublicChannelsByIdsForTeam) <https://developers.mattermost.com/api-documentation/#/operations/GetPublicChannelsByIdsForTeam>`_

        """
        return self.client.post(f"/api/v4/teams/{team_id}/channels/ids", options=options)

    def get_channel_members_timezones(self, channel_id: str):
        """Get timezones in a channel

        channel_id: Channel GUID

        `Read in Mattermost API docs (channels - GetChannelMembersTimezones) <https://developers.mattermost.com/api-documentation/#/operations/GetChannelMembersTimezones>`_

        """
        return self.client.get(f"/api/v4/channels/{channel_id}/timezones")

    def get_channel(self, channel_id: str):
        """Get a channel

        channel_id: Channel GUID

        `Read in Mattermost API docs (channels - GetChannel) <https://developers.mattermost.com/api-documentation/#/operations/GetChannel>`_

        """
        return self.client.get(f"/api/v4/channels/{channel_id}")

    def update_channel(
        self,
        channel_id: str,
        id: str,
        name: str | None = None,
        display_name: str | None = None,
        purpose: str | None = None,
        header: str | None = None,
    ):
        """Update a channel

        channel_id: Channel GUID
        id: The channel's id, not updatable
        name: The unique handle for the channel, will be present in the channel URL
        display_name: The non-unique UI name for the channel
        purpose: A short description of the purpose of the channel
        header: Markdown-formatted text to display in the header of the channel

        `Read in Mattermost API docs (channels - UpdateChannel) <https://developers.mattermost.com/api-documentation/#/operations/UpdateChannel>`_

        """
        __options = {"id": id, "name": name, "display_name": display_name, "purpose": purpose, "header": header}
        return self.client.put(f"/api/v4/channels/{channel_id}", options=__options)

    def delete_channel(self, channel_id: str):
        """Delete a channel

        channel_id: Channel GUID

        `Read in Mattermost API docs (channels - DeleteChannel) <https://developers.mattermost.com/api-documentation/#/operations/DeleteChannel>`_

        """
        return self.client.delete(f"/api/v4/channels/{channel_id}")

    def patch_channel(
        self,
        channel_id: str,
        name: str | None = None,
        display_name: str | None = None,
        purpose: str | None = None,
        header: str | None = None,
        banner_info: Any | None = None,
    ):
        """Patch a channel

        channel_id: Channel GUID
        name: The unique handle for the channel, will be present in the channel URL
        display_name: The non-unique UI name for the channel
        purpose: A short description of the purpose of the channel
        header: Markdown-formatted text to display in the header of the channel
        banner_info:

        `Read in Mattermost API docs (channels - PatchChannel) <https://developers.mattermost.com/api-documentation/#/operations/PatchChannel>`_

        """
        __options = {
            "name": name,
            "display_name": display_name,
            "purpose": purpose,
            "header": header,
            "banner_info": banner_info,
        }
        return self.client.put(f"/api/v4/channels/{channel_id}/patch", options=__options)

    def update_channel_privacy(self, channel_id: str, privacy: str):
        """Update channel's privacy

        channel_id: Channel GUID
        privacy: Channel privacy setting: 'O' for a public channel, 'P' for a private channel

        `Read in Mattermost API docs (channels - UpdateChannelPrivacy) <https://developers.mattermost.com/api-documentation/#/operations/UpdateChannelPrivacy>`_

        """
        __options = {"privacy": privacy}
        return self.client.put(f"/api/v4/channels/{channel_id}/privacy", options=__options)

    def restore_channel(self, channel_id: str):
        """Restore a channel

        channel_id: Channel GUID

        `Read in Mattermost API docs (channels - RestoreChannel) <https://developers.mattermost.com/api-documentation/#/operations/RestoreChannel>`_

        """
        return self.client.post(f"/api/v4/channels/{channel_id}/restore")

    def move_channel(self, channel_id: str, team_id: str, force: bool | None = None):
        """Move a channel

        channel_id: Channel GUID
        team_id:
        force: Remove members those are not member of target team before moving the channel.

        `Read in Mattermost API docs (channels - MoveChannel) <https://developers.mattermost.com/api-documentation/#/operations/MoveChannel>`_

        """
        __options = {"team_id": team_id, "force": force}
        return self.client.post(f"/api/v4/channels/{channel_id}/move", options=__options)

    def get_channel_stats(self, channel_id: str):
        """Get channel statistics

        channel_id: Channel GUID

        `Read in Mattermost API docs (channels - GetChannelStats) <https://developers.mattermost.com/api-documentation/#/operations/GetChannelStats>`_

        """
        return self.client.get(f"/api/v4/channels/{channel_id}/stats")

    def get_pinned_posts(self, channel_id: str):
        """Get a channel's pinned posts

        channel_id: Channel GUID

        `Read in Mattermost API docs (channels - GetPinnedPosts) <https://developers.mattermost.com/api-documentation/#/operations/GetPinnedPosts>`_

        """
        return self.client.get(f"/api/v4/channels/{channel_id}/pinned")

    def get_public_channels_for_team(self, team_id: str, page: int | None = 0, per_page: int | None = 60):
        """Get public channels

        team_id: Team GUID
        page: The page to select.
        per_page: The number of public channels per page.

        `Read in Mattermost API docs (channels - GetPublicChannelsForTeam) <https://developers.mattermost.com/api-documentation/#/operations/GetPublicChannelsForTeam>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get(f"/api/v4/teams/{team_id}/channels", params=__params)

    def get_private_channels_for_team(self, team_id: str, page: int | None = 0, per_page: int | None = 60):
        """Get private channels

        team_id: Team GUID
        page: The page to select.
        per_page: The number of private channels per page.

        `Read in Mattermost API docs (channels - GetPrivateChannelsForTeam) <https://developers.mattermost.com/api-documentation/#/operations/GetPrivateChannelsForTeam>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get(f"/api/v4/teams/{team_id}/channels/private", params=__params)

    def get_deleted_channels_for_team(self, team_id: str, page: int | None = 0, per_page: int | None = 60):
        """Get deleted channels

        team_id: Team GUID
        page: The page to select.
        per_page: The number of public channels per page.

        `Read in Mattermost API docs (channels - GetDeletedChannelsForTeam) <https://developers.mattermost.com/api-documentation/#/operations/GetDeletedChannelsForTeam>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get(f"/api/v4/teams/{team_id}/channels/deleted", params=__params)

    def autocomplete_channels_for_team(self, team_id: str, name: str):
        """Autocomplete channels

        team_id: Team GUID
        name: Name or display name

        `Read in Mattermost API docs (channels - AutocompleteChannelsForTeam) <https://developers.mattermost.com/api-documentation/#/operations/AutocompleteChannelsForTeam>`_

        """
        __params = {"name": name}
        return self.client.get(f"/api/v4/teams/{team_id}/channels/autocomplete", params=__params)

    def autocomplete_channels_for_team_for_search(self, team_id: str, name: str):
        """Autocomplete channels for search

        team_id: Team GUID
        name: Name or display name

        `Read in Mattermost API docs (channels - AutocompleteChannelsForTeamForSearch) <https://developers.mattermost.com/api-documentation/#/operations/AutocompleteChannelsForTeamForSearch>`_

        """
        __params = {"name": name}
        return self.client.get(f"/api/v4/teams/{team_id}/channels/search_autocomplete", params=__params)

    def search_channels(self, team_id: str, term: str):
        """Search channels

        team_id: Team GUID
        term: The search term to match against the name or display name of channels

        `Read in Mattermost API docs (channels - SearchChannels) <https://developers.mattermost.com/api-documentation/#/operations/SearchChannels>`_

        """
        __options = {"term": term}
        return self.client.post(f"/api/v4/teams/{team_id}/channels/search", options=__options)

    def get_channel_by_name(self, team_id: str, channel_name: str, include_deleted: bool | None = False):
        """Get a channel by name

        team_id: Team GUID
        channel_name: Channel Name
        include_deleted: Defines if deleted channels should be returned or not (Mattermost Server 5.26.0+)

        `Read in Mattermost API docs (channels - GetChannelByName) <https://developers.mattermost.com/api-documentation/#/operations/GetChannelByName>`_

        """
        __params = {"include_deleted": include_deleted}
        return self.client.get(f"/api/v4/teams/{team_id}/channels/name/{channel_name}", params=__params)

    def get_channel_by_name_for_team_name(
        self, team_name: str, channel_name: str, include_deleted: bool | None = False
    ):
        """Get a channel by name and team name

        team_name: Team Name
        channel_name: Channel Name
        include_deleted: Defines if deleted channels should be returned or not (Mattermost Server 5.26.0+)

        `Read in Mattermost API docs (channels - GetChannelByNameForTeamName) <https://developers.mattermost.com/api-documentation/#/operations/GetChannelByNameForTeamName>`_

        """
        __params = {"include_deleted": include_deleted}
        return self.client.get(f"/api/v4/teams/name/{team_name}/channels/name/{channel_name}", params=__params)

    def get_channel_members(self, channel_id: str, page: int | None = 0, per_page: int | None = 60):
        """Get channel members

        channel_id: Channel GUID
        page: The page to select.
        per_page: The number of members per page.

        `Read in Mattermost API docs (channels - GetChannelMembers) <https://developers.mattermost.com/api-documentation/#/operations/GetChannelMembers>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get(f"/api/v4/channels/{channel_id}/members", params=__params)

    def add_channel_member(
        self,
        channel_id: str,
        user_id: str | None = None,
        user_ids: list[str] | None = None,
        post_root_id: str | None = None,
    ):
        """Add user(s) to channel

        channel_id: The channel ID
        user_id: The ID of user to add into the channel, for backwards compatibility.
        user_ids: The IDs of users to add into the channel, required if 'user_id' doess not exist.
        post_root_id: The ID of root post where link to add channel member originates

        `Read in Mattermost API docs (channels - AddChannelMember) <https://developers.mattermost.com/api-documentation/#/operations/AddChannelMember>`_

        """
        __options = {"user_id": user_id, "user_ids": user_ids, "post_root_id": post_root_id}
        return self.client.post(f"/api/v4/channels/{channel_id}/members", options=__options)

    def get_channel_members_by_ids(self, channel_id: str, options: list[str]):
        """Get channel members by ids

        channel_id: Channel GUID

        `Read in Mattermost API docs (channels - GetChannelMembersByIds) <https://developers.mattermost.com/api-documentation/#/operations/GetChannelMembersByIds>`_

        """
        return self.client.post(f"/api/v4/channels/{channel_id}/members/ids", options=options)

    def get_channel_member(self, channel_id: str, user_id: str):
        """Get channel member

        channel_id: Channel GUID
        user_id: User GUID

        `Read in Mattermost API docs (channels - GetChannelMember) <https://developers.mattermost.com/api-documentation/#/operations/GetChannelMember>`_

        """
        return self.client.get(f"/api/v4/channels/{channel_id}/members/{user_id}")

    def remove_user_from_channel(self, channel_id: str, user_id: str):
        """Remove user from channel

        channel_id: Channel GUID
        user_id: User GUID

        `Read in Mattermost API docs (channels - RemoveUserFromChannel) <https://developers.mattermost.com/api-documentation/#/operations/RemoveUserFromChannel>`_

        """
        return self.client.delete(f"/api/v4/channels/{channel_id}/members/{user_id}")

    def update_channel_roles(self, channel_id: str, user_id: str, roles: str):
        """Update channel roles

        channel_id: Channel GUID
        user_id: User GUID
        roles:

        `Read in Mattermost API docs (channels - UpdateChannelRoles) <https://developers.mattermost.com/api-documentation/#/operations/UpdateChannelRoles>`_

        """
        __options = {"roles": roles}
        return self.client.put(f"/api/v4/channels/{channel_id}/members/{user_id}/roles", options=__options)

    def update_channel_member_scheme_roles(self, channel_id: str, user_id: str, scheme_admin: bool, scheme_user: bool):
        """Update the scheme-derived roles of a channel member.

        channel_id: Channel GUID
        user_id: User GUID
        scheme_admin:
        scheme_user:

        `Read in Mattermost API docs (channels - UpdateChannelMemberSchemeRoles) <https://developers.mattermost.com/api-documentation/#/operations/UpdateChannelMemberSchemeRoles>`_

        """
        __options = {"scheme_admin": scheme_admin, "scheme_user": scheme_user}
        return self.client.put(f"/api/v4/channels/{channel_id}/members/{user_id}/schemeRoles", options=__options)

    def update_channel_notify_props(self, channel_id: str, user_id: str, options: Any):
        """Update channel notifications

        channel_id: Channel GUID
        user_id: User GUID

        `Read in Mattermost API docs (channels - UpdateChannelNotifyProps) <https://developers.mattermost.com/api-documentation/#/operations/UpdateChannelNotifyProps>`_

        """
        return self.client.put(f"/api/v4/channels/{channel_id}/members/{user_id}/notify_props", options=options)

    def view_channel(self, user_id: str, channel_id: str, prev_channel_id: str | None = None):
        """View channel

        user_id: User ID to perform the view action for
        channel_id: The channel ID that is being viewed. Use a blank string to indicate that all channels have lost focus.
        prev_channel_id: The channel ID of the previous channel, used when switching channels. Providing this ID will cause push notifications to clear on the channel being switched to.

        `Read in Mattermost API docs (channels - ViewChannel) <https://developers.mattermost.com/api-documentation/#/operations/ViewChannel>`_

        """
        __options = {"channel_id": channel_id, "prev_channel_id": prev_channel_id}
        return self.client.post(f"/api/v4/channels/members/{user_id}/view", options=__options)

    def get_channel_members_for_user(self, user_id: str, team_id: str):
        """Get channel memberships and roles for a user

        user_id: User GUID
        team_id: Team GUID

        `Read in Mattermost API docs (channels - GetChannelMembersForUser) <https://developers.mattermost.com/api-documentation/#/operations/GetChannelMembersForUser>`_

        """
        return self.client.get(f"/api/v4/users/{user_id}/teams/{team_id}/channels/members")

    def get_channels_for_team_for_user(
        self, user_id: str, team_id: str, include_deleted: bool | None = False, last_delete_at: int | None = 0
    ):
        """Get channels for user

        user_id: User GUID
        team_id: Team GUID
        include_deleted: Defines if deleted channels should be returned or not
        last_delete_at: Filters the deleted channels by this time in epoch format. Does not have any effect if include_deleted is set to false.

        `Read in Mattermost API docs (channels - GetChannelsForTeamForUser) <https://developers.mattermost.com/api-documentation/#/operations/GetChannelsForTeamForUser>`_

        """
        __params = {"include_deleted": include_deleted, "last_delete_at": last_delete_at}
        return self.client.get(f"/api/v4/users/{user_id}/teams/{team_id}/channels", params=__params)

    def get_channels_for_user(self, user_id: str, last_delete_at: int | None = 0, include_deleted: bool | None = False):
        """Get all channels from all teams

        user_id: The ID of the user. This can also be "me" which will point to the current user.
        last_delete_at: Filters the deleted channels by this time in epoch format. Does not have any effect if include_deleted is set to false.
        include_deleted: Defines if deleted channels should be returned or not

        `Read in Mattermost API docs (channels - GetChannelsForUser) <https://developers.mattermost.com/api-documentation/#/operations/GetChannelsForUser>`_

        """
        __params = {"last_delete_at": last_delete_at, "include_deleted": include_deleted}
        return self.client.get(f"/api/v4/users/{user_id}/channels", params=__params)

    def get_channel_unread(self, user_id: str, channel_id: str):
        """Get unread messages

        user_id: User GUID
        channel_id: Channel GUID

        `Read in Mattermost API docs (channels - GetChannelUnread) <https://developers.mattermost.com/api-documentation/#/operations/GetChannelUnread>`_

        """
        return self.client.get(f"/api/v4/users/{user_id}/channels/{channel_id}/unread")

    def update_channel_scheme(self, channel_id: str, scheme_id: str):
        """Set a channel's scheme

        channel_id: Channel GUID
        scheme_id: The ID of the scheme.

        `Read in Mattermost API docs (channels - UpdateChannelScheme) <https://developers.mattermost.com/api-documentation/#/operations/UpdateChannelScheme>`_

        """
        __options = {"scheme_id": scheme_id}
        return self.client.put(f"/api/v4/channels/{channel_id}/scheme", options=__options)

    def channel_members_minus_group_members(
        self, channel_id: str, group_ids: str = "", page: int | None = 0, per_page: int | None = 0
    ):
        """Channel members minus group members.

        channel_id: Channel GUID
        group_ids: A comma-separated list of group ids.
        page: The page to select.
        per_page: The number of users per page.

        `Read in Mattermost API docs (channels - ChannelMembersMinusGroupMembers) <https://developers.mattermost.com/api-documentation/#/operations/ChannelMembersMinusGroupMembers>`_

        """
        __params = {"group_ids": group_ids, "page": page, "per_page": per_page}
        return self.client.get(f"/api/v4/channels/{channel_id}/members_minus_group_members", params=__params)

    def get_channel_member_counts_by_group(self, channel_id: str, include_timezones: bool | None = False):
        """Channel members counts for each group that has atleast one member in the channel

        channel_id: Channel GUID
        include_timezones: Defines if member timezone counts should be returned or not

        `Read in Mattermost API docs (channels - GetChannelMemberCountsByGroup) <https://developers.mattermost.com/api-documentation/#/operations/GetChannelMemberCountsByGroup>`_

        """
        __params = {"include_timezones": include_timezones}
        return self.client.get(f"/api/v4/channels/{channel_id}/member_counts_by_group", params=__params)

    def get_channel_moderations(self, channel_id: str):
        """Get information about channel's moderation.

        channel_id: Channel GUID

        `Read in Mattermost API docs (channels - GetChannelModerations) <https://developers.mattermost.com/api-documentation/#/operations/GetChannelModerations>`_

        """
        return self.client.get(f"/api/v4/channels/{channel_id}/moderations")

    def patch_channel_moderations(self, channel_id: str, options: Any):
        """Update a channel's moderation settings.

        channel_id: Channel GUID

        `Read in Mattermost API docs (channels - PatchChannelModerations) <https://developers.mattermost.com/api-documentation/#/operations/PatchChannelModerations>`_

        """
        return self.client.put(f"/api/v4/channels/{channel_id}/moderations/patch", options=options)

    def get_sidebar_categories_for_team_for_user(self, team_id: str, user_id: str):
        """Get user's sidebar categories

        team_id: Team GUID
        user_id: User GUID

        `Read in Mattermost API docs (channels - GetSidebarCategoriesForTeamForUser) <https://developers.mattermost.com/api-documentation/#/operations/GetSidebarCategoriesForTeamForUser>`_

        """
        return self.client.get(f"/api/v4/users/{user_id}/teams/{team_id}/channels/categories")

    def create_sidebar_category_for_team_for_user(self, team_id: str, user_id: str, options: Any):
        """Create user's sidebar category

        team_id: Team GUID
        user_id: User GUID

        `Read in Mattermost API docs (channels - CreateSidebarCategoryForTeamForUser) <https://developers.mattermost.com/api-documentation/#/operations/CreateSidebarCategoryForTeamForUser>`_

        """
        return self.client.post(f"/api/v4/users/{user_id}/teams/{team_id}/channels/categories", options=options)

    def update_sidebar_categories_for_team_for_user(self, team_id: str, user_id: str, options: list[Any]):
        """Update user's sidebar categories

        team_id: Team GUID
        user_id: User GUID

        `Read in Mattermost API docs (channels - UpdateSidebarCategoriesForTeamForUser) <https://developers.mattermost.com/api-documentation/#/operations/UpdateSidebarCategoriesForTeamForUser>`_

        """
        return self.client.put(f"/api/v4/users/{user_id}/teams/{team_id}/channels/categories", options=options)

    def get_sidebar_category_order_for_team_for_user(self, team_id: str, user_id: str):
        """Get user's sidebar category order

        team_id: Team GUID
        user_id: User GUID

        `Read in Mattermost API docs (channels - GetSidebarCategoryOrderForTeamForUser) <https://developers.mattermost.com/api-documentation/#/operations/GetSidebarCategoryOrderForTeamForUser>`_

        """
        return self.client.get(f"/api/v4/users/{user_id}/teams/{team_id}/channels/categories/order")

    def update_sidebar_category_order_for_team_for_user(self, team_id: str, user_id: str, options: list[str]):
        """Update user's sidebar category order

        team_id: Team GUID
        user_id: User GUID

        `Read in Mattermost API docs (channels - UpdateSidebarCategoryOrderForTeamForUser) <https://developers.mattermost.com/api-documentation/#/operations/UpdateSidebarCategoryOrderForTeamForUser>`_

        """
        return self.client.put(f"/api/v4/users/{user_id}/teams/{team_id}/channels/categories/order", options=options)

    def get_sidebar_category_for_team_for_user(self, team_id: str, user_id: str, category_id: str):
        """Get sidebar category

        team_id: Team GUID
        user_id: User GUID
        category_id: Category GUID

        `Read in Mattermost API docs (channels - GetSidebarCategoryForTeamForUser) <https://developers.mattermost.com/api-documentation/#/operations/GetSidebarCategoryForTeamForUser>`_

        """
        return self.client.get(f"/api/v4/users/{user_id}/teams/{team_id}/channels/categories/{category_id}")

    def update_sidebar_category_for_team_for_user(self, team_id: str, user_id: str, category_id: str, options: Any):
        """Update sidebar category

        team_id: Team GUID
        user_id: User GUID
        category_id: Category GUID

        `Read in Mattermost API docs (channels - UpdateSidebarCategoryForTeamForUser) <https://developers.mattermost.com/api-documentation/#/operations/UpdateSidebarCategoryForTeamForUser>`_

        """
        return self.client.put(
            f"/api/v4/users/{user_id}/teams/{team_id}/channels/categories/{category_id}", options=options
        )

    def remove_sidebar_category_for_team_for_user(self, team_id: str, user_id: str, category_id: str):
        """Delete sidebar category

        team_id: Team GUID
        user_id: User GUID
        category_id: Category GUID

        `Read in Mattermost API docs (channels - RemoveSidebarCategoryForTeamForUser) <https://developers.mattermost.com/api-documentation/#/operations/RemoveSidebarCategoryForTeamForUser>`_

        """
        return self.client.delete(f"/api/v4/users/{user_id}/teams/{team_id}/channels/categories/{category_id}")

    def get_group_message_members_common_teams(self, channel_id: str):
        """Get common teams for members of a Group Message.

        channel_id: Channel GUID

        `Read in Mattermost API docs (channels - GetGroupMessageMembersCommonTeams) <https://developers.mattermost.com/api-documentation/#/operations/GetGroupMessageMembersCommonTeams>`_

        """
        return self.client.get(f"/api/v4/channels/{channel_id}/common_teams")

    def get_channel_access_control_attributes(self, channel_id: str):
        """Get access control attributes for a channel

        channel_id: The ID of the channel.

        `Read in Mattermost API docs (channels - GetChannelAccessControlAttributes) <https://developers.mattermost.com/api-documentation/#/operations/GetChannelAccessControlAttributes>`_

        """
        return self.client.get(f"/api/v4/channels/{channel_id}/access_control/attributes")



from ._base import Base

__all__ = ["Jobs"]


class Jobs(Base):

    def get_jobs(self, params=None):
        """Get the jobs.

        page: The page to select.
        per_page: The number of jobs per page.
        job_type: The type of jobs to fetch.
        status: The status of jobs to fetch.

        `Read in Mattermost API docs (jobs - GetJobs) <https://developers.mattermost.com/api-documentation/#/operations/GetJobs>`_

        """
        return self.client.get("""/api/v4/jobs""", params=params)

    def create_job(self, options):
        """Create a new job.

        type: The type of job to create
        data: An object containing any additional data required for this job type

        `Read in Mattermost API docs (jobs - CreateJob) <https://developers.mattermost.com/api-documentation/#/operations/CreateJob>`_

        """
        return self.client.post("""/api/v4/jobs""", options=options)

    def get_job(self, job_id):
        """Get a job.

        job_id: Job GUID

        `Read in Mattermost API docs (jobs - GetJob) <https://developers.mattermost.com/api-documentation/#/operations/GetJob>`_

        """
        return self.client.get(f"/api/v4/jobs/{job_id}")

    def download_job(self, job_id):
        """Download the results of a job.

        job_id: Job GUID

        `Read in Mattermost API docs (jobs - DownloadJob) <https://developers.mattermost.com/api-documentation/#/operations/DownloadJob>`_

        """
        return self.client.get(f"/api/v4/jobs/{job_id}/download")

    def cancel_job(self, job_id):
        """Cancel a job.

        job_id: Job GUID

        `Read in Mattermost API docs (jobs - CancelJob) <https://developers.mattermost.com/api-documentation/#/operations/CancelJob>`_

        """
        return self.client.post(f"/api/v4/jobs/{job_id}/cancel")

    def get_jobs_by_type(self, type, params=None):
        """Get the jobs of the given type.

        type: Job type
        page: The page to select.
        per_page: The number of jobs per page.

        `Read in Mattermost API docs (jobs - GetJobsByType) <https://developers.mattermost.com/api-documentation/#/operations/GetJobsByType>`_

        """
        return self.client.get(f"/api/v4/jobs/type/{type}", params=params)

    def update_job_status(self, job_id, options):
        """Update the status of a job

        job_id: Job GUID
        status: The status you want to set
        force: Set this to true to bypass status restrictions

        `Read in Mattermost API docs (jobs - UpdateJobStatus) <https://developers.mattermost.com/api-documentation/#/operations/UpdateJobStatus>`_

        """
        return self.client.patch(f"/api/v4/jobs/{job_id}/status", options=options)



from ._base import Base
from typing import Any, BinaryIO

__all__ = ["Brand"]


class Brand(Base):

    def get_brand_image(self):
        """Get brand image
        `Read in Mattermost API docs (brand - GetBrandImage) <https://developers.mattermost.com/api-documentation/#/operations/GetBrandImage>`_

        """
        return self.client.get("""/api/v4/brand/image""")

    def upload_brand_image(self, image: BinaryIO):
        """Upload brand image

        image: The image to be uploaded

        `Read in Mattermost API docs (brand - UploadBrandImage) <https://developers.mattermost.com/api-documentation/#/operations/UploadBrandImage>`_

        """
        __files = {"image": image}
        return self.client.post("""/api/v4/brand/image""", files=__files)

    def delete_brand_image(self):
        """Delete current brand image
        `Read in Mattermost API docs (brand - DeleteBrandImage) <https://developers.mattermost.com/api-documentation/#/operations/DeleteBrandImage>`_

        """
        return self.client.delete("""/api/v4/brand/image""")



from ._base import Base
from typing import Any, BinaryIO

__all__ = ["DataRetention"]


class DataRetention(Base):

    def get_team_policies_for_user(self, user_id: str, page: int | None = 0, per_page: int | None = 60):
        """Get the policies which are applied to a user's teams

        user_id: The ID of the user. This can also be "me" which will point to the current user.
        page: The page to select.
        per_page: The number of policies per page.

        `Read in Mattermost API docs (data_retention - GetTeamPoliciesForUser) <https://developers.mattermost.com/api-documentation/#/operations/GetTeamPoliciesForUser>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get(f"/api/v4/users/{user_id}/data_retention/team_policies", params=__params)

    def get_channel_policies_for_user(self, user_id: str, page: int | None = 0, per_page: int | None = 60):
        """Get the policies which are applied to a user's channels

        user_id: The ID of the user. This can also be "me" which will point to the current user.
        page: The page to select.
        per_page: The number of policies per page.

        `Read in Mattermost API docs (data_retention - GetChannelPoliciesForUser) <https://developers.mattermost.com/api-documentation/#/operations/GetChannelPoliciesForUser>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get(f"/api/v4/users/{user_id}/data_retention/channel_policies", params=__params)

    def get_data_retention_policy(self):
        """Get the global data retention policy
        `Read in Mattermost API docs (data_retention - GetDataRetentionPolicy) <https://developers.mattermost.com/api-documentation/#/operations/GetDataRetentionPolicy>`_

        """
        return self.client.get("""/api/v4/data_retention/policy""")

    def get_data_retention_policies_count(self):
        """Get the number of granular data retention policies
        `Read in Mattermost API docs (data_retention - GetDataRetentionPoliciesCount) <https://developers.mattermost.com/api-documentation/#/operations/GetDataRetentionPoliciesCount>`_

        """
        return self.client.get("""/api/v4/data_retention/policies_count""")

    def get_data_retention_policies(self, page: int | None = 0, per_page: int | None = 60):
        """Get the granular data retention policies

        page: The page to select.
        per_page: The number of policies per page.

        `Read in Mattermost API docs (data_retention - GetDataRetentionPolicies) <https://developers.mattermost.com/api-documentation/#/operations/GetDataRetentionPolicies>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get("""/api/v4/data_retention/policies""", params=__params)

    def create_data_retention_policy(self, options: Any):
        """Create a new granular data retention policy
        `Read in Mattermost API docs (data_retention - CreateDataRetentionPolicy) <https://developers.mattermost.com/api-documentation/#/operations/CreateDataRetentionPolicy>`_

        """
        return self.client.post("""/api/v4/data_retention/policies""", options=options)

    def get_data_retention_policy_by_id(self, policy_id: str):
        """Get a granular data retention policy

        policy_id: The ID of the granular retention policy.

        `Read in Mattermost API docs (data_retention - GetDataRetentionPolicyByID) <https://developers.mattermost.com/api-documentation/#/operations/GetDataRetentionPolicyByID>`_

        """
        return self.client.get(f"/api/v4/data_retention/policies/{policy_id}")

    def patch_data_retention_policy(self, policy_id: str, options: Any):
        """Patch a granular data retention policy

        policy_id: The ID of the granular retention policy.

        `Read in Mattermost API docs (data_retention - PatchDataRetentionPolicy) <https://developers.mattermost.com/api-documentation/#/operations/PatchDataRetentionPolicy>`_

        """
        return self.client.patch(f"/api/v4/data_retention/policies/{policy_id}", options=options)

    def delete_data_retention_policy(self, policy_id: str):
        """Delete a granular data retention policy

        policy_id: The ID of the granular retention policy.

        `Read in Mattermost API docs (data_retention - DeleteDataRetentionPolicy) <https://developers.mattermost.com/api-documentation/#/operations/DeleteDataRetentionPolicy>`_

        """
        return self.client.delete(f"/api/v4/data_retention/policies/{policy_id}")

    def get_teams_for_retention_policy(self, policy_id: str, page: int | None = 0, per_page: int | None = 60):
        """Get the teams for a granular data retention policy

        policy_id: The ID of the granular retention policy.
        page: The page to select.
        per_page: The number of teams per page.

        `Read in Mattermost API docs (data_retention - GetTeamsForRetentionPolicy) <https://developers.mattermost.com/api-documentation/#/operations/GetTeamsForRetentionPolicy>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get(f"/api/v4/data_retention/policies/{policy_id}/teams", params=__params)

    def add_teams_to_retention_policy(self, policy_id: str, options: list[str]):
        """Add teams to a granular data retention policy

        policy_id: The ID of the granular retention policy.

        `Read in Mattermost API docs (data_retention - AddTeamsToRetentionPolicy) <https://developers.mattermost.com/api-documentation/#/operations/AddTeamsToRetentionPolicy>`_

        """
        return self.client.post(f"/api/v4/data_retention/policies/{policy_id}/teams", options=options)

    def remove_teams_from_retention_policy(self, policy_id: str, params: list[str]):
        """Delete teams from a granular data retention policy

        policy_id: The ID of the granular retention policy.

        `Read in Mattermost API docs (data_retention - RemoveTeamsFromRetentionPolicy) <https://developers.mattermost.com/api-documentation/#/operations/RemoveTeamsFromRetentionPolicy>`_

        """
        return self.client.delete(f"/api/v4/data_retention/policies/{policy_id}/teams", params=params)

    def search_teams_for_retention_policy(self, policy_id: str, term: str | None = None):
        """Search for the teams in a granular data retention policy

        policy_id: The ID of the granular retention policy.
        term: The search term to match against the name or display name of teams

        `Read in Mattermost API docs (data_retention - SearchTeamsForRetentionPolicy) <https://developers.mattermost.com/api-documentation/#/operations/SearchTeamsForRetentionPolicy>`_

        """
        __options = {"term": term}
        return self.client.post(f"/api/v4/data_retention/policies/{policy_id}/teams/search", options=__options)

    def get_channels_for_retention_policy(self, policy_id: str, page: int | None = 0, per_page: int | None = 60):
        """Get the channels for a granular data retention policy

        policy_id: The ID of the granular retention policy.
        page: The page to select.
        per_page: The number of channels per page.

        `Read in Mattermost API docs (data_retention - GetChannelsForRetentionPolicy) <https://developers.mattermost.com/api-documentation/#/operations/GetChannelsForRetentionPolicy>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get(f"/api/v4/data_retention/policies/{policy_id}/channels", params=__params)

    def add_channels_to_retention_policy(self, policy_id: str, options: list[str]):
        """Add channels to a granular data retention policy

        policy_id: The ID of the granular retention policy.

        `Read in Mattermost API docs (data_retention - AddChannelsToRetentionPolicy) <https://developers.mattermost.com/api-documentation/#/operations/AddChannelsToRetentionPolicy>`_

        """
        return self.client.post(f"/api/v4/data_retention/policies/{policy_id}/channels", options=options)

    def remove_channels_from_retention_policy(self, policy_id: str, params: list[str]):
        """Delete channels from a granular data retention policy

        policy_id: The ID of the granular retention policy.

        `Read in Mattermost API docs (data_retention - RemoveChannelsFromRetentionPolicy) <https://developers.mattermost.com/api-documentation/#/operations/RemoveChannelsFromRetentionPolicy>`_

        """
        return self.client.delete(f"/api/v4/data_retention/policies/{policy_id}/channels", params=params)

    def search_channels_for_retention_policy(
        self,
        policy_id: str,
        term: str | None = None,
        team_ids: list[str] | None = None,
        public: bool | None = None,
        private: bool | None = None,
        deleted: bool | None = None,
    ):
        """Search for the channels in a granular data retention policy

        policy_id: The ID of the granular retention policy.
        term: The string to search in the channel name, display name, and purpose.
        team_ids: Filters results to channels belonging to the given team ids

        public: Filters results to only return Public / Open channels, can be used in conjunction with ``private`` to return both ``public`` and ``private`` channels

        private: Filters results to only return Private channels, can be used in conjunction with ``public`` to return both ``private`` and ``public`` channels

        deleted: Filters results to only return deleted / archived channels


        `Read in Mattermost API docs (data_retention - SearchChannelsForRetentionPolicy) <https://developers.mattermost.com/api-documentation/#/operations/SearchChannelsForRetentionPolicy>`_

        """
        __options = {"term": term, "team_ids": team_ids, "public": public, "private": private, "deleted": deleted}
        return self.client.post(f"/api/v4/data_retention/policies/{policy_id}/channels/search", options=__options)



from ._base import Base
from typing import Any, BinaryIO

__all__ = ["Metrics"]


class Metrics(Base):

    def submit_performance_report(
        self,
        version: str,
        start: int,
        end: int,
        client_id: str | None = None,
        labels: list[str] | None = None,
        counters: list[dict[str, Any]] | None = None,
        histograms: list[dict[str, Any]] | None = None,
    ):
        """Report client performance metrics

        version: An identifier for the schema of the data being submitted which currently must be "0.1.0"
        client_id: Not currently used
        labels: Labels to be applied to all metrics when recorded by the metrics backend
        start: The time in milliseconds of the first metric in this report
        end: The time in milliseconds of the last metric in this report
        counters: An array of counter metrics to be reported
        histograms: An array of histogram measurements to be reported

        `Read in Mattermost API docs (metrics - SubmitPerformanceReport) <https://developers.mattermost.com/api-documentation/#/operations/SubmitPerformanceReport>`_

        """
        __options = {
            "version": version,
            "client_id": client_id,
            "labels": labels,
            "start": start,
            "end": end,
            "counters": counters,
            "histograms": histograms,
        }
        return self.client.post("""/api/v4/client_perf""", options=__options)



from ._base import Base

__all__ = ["CustomProfileAttributes"]


class CustomProfileAttributes(Base):

    def list_all_cpa_fields(self):
        """List all the Custom Profile Attributes fields
        `Read in Mattermost API docs (custom_profile_attributes - ListAllCPAFields) <https://developers.mattermost.com/api-documentation/#/operations/ListAllCPAFields>`_

        """
        return self.client.get("""/api/v4/custom_profile_attributes/fields""")

    def create_cpa_field(self, options=None):
        """Create a Custom Profile Attribute field

        name:
        type:
        attrs:

        `Read in Mattermost API docs (custom_profile_attributes - CreateCPAField) <https://developers.mattermost.com/api-documentation/#/operations/CreateCPAField>`_

        """
        return self.client.post("""/api/v4/custom_profile_attributes/fields""", options=options)

    def patch_cpa_field(self, field_id, options):
        """Patch a Custom Profile Attribute field

        field_id: Custom Profile Attribute field GUID
        name:
        type:
        attrs:

        `Read in Mattermost API docs (custom_profile_attributes - PatchCPAField) <https://developers.mattermost.com/api-documentation/#/operations/PatchCPAField>`_

        """
        return self.client.patch(f"/api/v4/custom_profile_attributes/fields/{field_id}", options=options)

    def delete_cpa_field(self, field_id):
        """Delete a Custom Profile Attribute field

        field_id: Custom Profile Attribute field GUID

        `Read in Mattermost API docs (custom_profile_attributes - DeleteCPAField) <https://developers.mattermost.com/api-documentation/#/operations/DeleteCPAField>`_

        """
        return self.client.delete(f"/api/v4/custom_profile_attributes/fields/{field_id}")

    def patch_cpa_values(self, options):
        """Patch Custom Profile Attribute values
        `Read in Mattermost API docs (custom_profile_attributes - PatchCPAValues) <https://developers.mattermost.com/api-documentation/#/operations/PatchCPAValues>`_

        """
        return self.client.patch("""/api/v4/custom_profile_attributes/values""", options=options)

    def get_cpa_group(self):
        """Get Custom Profile Attribute property group data
        `Read in Mattermost API docs (custom_profile_attributes - GetCPAGroup) <https://developers.mattermost.com/api-documentation/#/operations/GetCPAGroup>`_

        """
        return self.client.get("""/api/v4/custom_profile_attributes/group""")

    def list_cpa_values(self, user_id):
        """List Custom Profile Attribute values

        user_id: User GUID

        `Read in Mattermost API docs (custom_profile_attributes - ListCPAValues) <https://developers.mattermost.com/api-documentation/#/operations/ListCPAValues>`_

        """
        return self.client.get(f"/api/v4/users/{user_id}/custom_profile_attributes")

    def patch_cpa_values_for_user(self, user_id, options):
        """Update custom profile attribute values for a user

        user_id: User GUID

        `Read in Mattermost API docs (custom_profile_attributes - PatchCPAValuesForUser) <https://developers.mattermost.com/api-documentation/#/operations/PatchCPAValuesForUser>`_

        """
        return self.client.patch(f"/api/v4/users/{user_id}/custom_profile_attributes", options=options)



from ._base import Base
from typing import Any, BinaryIO

__all__ = ["Elasticsearch"]


class Elasticsearch(Base):

    def test_elasticsearch(self):
        """Test Elasticsearch configuration
        `Read in Mattermost API docs (elasticsearch - TestElasticsearch) <https://developers.mattermost.com/api-documentation/#/operations/TestElasticsearch>`_

        """
        return self.client.post("""/api/v4/elasticsearch/test""")

    def purge_elasticsearch_indexes(self):
        """Purge all Elasticsearch indexes
        `Read in Mattermost API docs (elasticsearch - PurgeElasticsearchIndexes) <https://developers.mattermost.com/api-documentation/#/operations/PurgeElasticsearchIndexes>`_

        """
        return self.client.post("""/api/v4/elasticsearch/purge_indexes""")



from ._base import Base
from typing import Any, BinaryIO

__all__ = ["PlaybookAutofollows"]


class PlaybookAutofollows(Base):

    def get_auto_follows(self, id: str):
        """Get the list of followers' user IDs of a playbook

        id: ID of the playbook to retrieve followers from.

        `Read in Mattermost API docs (playbook_autofollows - getAutoFollows) <https://developers.mattermost.com/api-documentation/#/operations/getAutoFollows>`_

        """
        return self.client.get(f"/plugins/playbooks/api/v0/playbooks/{id}/autofollows")



from ._base import Base
from typing import Any, BinaryIO

__all__ = ["Usage"]


class Usage(Base):

    def get_posts_usage(self):
        """Get current usage of posts
        `Read in Mattermost API docs (usage - GetPostsUsage) <https://developers.mattermost.com/api-documentation/#/operations/GetPostsUsage>`_

        """
        return self.client.get("""/api/v4/usage/posts""")

    def get_storage_usage(self):
        """Get the total file storage usage for the instance in bytes.
        `Read in Mattermost API docs (usage - GetStorageUsage) <https://developers.mattermost.com/api-documentation/#/operations/GetStorageUsage>`_

        """
        return self.client.get("""/api/v4/usage/storage""")



from ._base import Base
from typing import Any, BinaryIO

__all__ = ["Emoji"]


class Emoji(Base):

    def create_emoji(self, image: BinaryIO, emoji: str):
        """Create a custom emoji

        image: A file to be uploaded
        emoji: A JSON object containing a ``name`` field with the name of the emoji and a ``creator_id`` field with the id of the authenticated user.

        `Read in Mattermost API docs (emoji - CreateEmoji) <https://developers.mattermost.com/api-documentation/#/operations/CreateEmoji>`_

        """
        __files = {"image": image}
        __data = {"emoji": emoji}
        return self.client.post("""/api/v4/emoji""", files=__files, data=__data)

    def get_emoji_list(self, page: int | None = 0, per_page: int | None = 60, sort: str | None = ""):
        """Get a list of custom emoji

        page: The page to select.
        per_page: The number of emojis per page.
        sort: Either blank for no sorting or "name" to sort by emoji names. Minimum server version for sorting is 4.7.

        `Read in Mattermost API docs (emoji - GetEmojiList) <https://developers.mattermost.com/api-documentation/#/operations/GetEmojiList>`_

        """
        __params = {"page": page, "per_page": per_page, "sort": sort}
        return self.client.get("""/api/v4/emoji""", params=__params)

    def get_emoji(self, emoji_id: str):
        """Get a custom emoji

        emoji_id: Emoji GUID

        `Read in Mattermost API docs (emoji - GetEmoji) <https://developers.mattermost.com/api-documentation/#/operations/GetEmoji>`_

        """
        return self.client.get(f"/api/v4/emoji/{emoji_id}")

    def delete_emoji(self, emoji_id: str):
        """Delete a custom emoji

        emoji_id: Emoji GUID

        `Read in Mattermost API docs (emoji - DeleteEmoji) <https://developers.mattermost.com/api-documentation/#/operations/DeleteEmoji>`_

        """
        return self.client.delete(f"/api/v4/emoji/{emoji_id}")

    def get_emoji_by_name(self, emoji_name: str):
        """Get a custom emoji by name

        emoji_name: Emoji name

        `Read in Mattermost API docs (emoji - GetEmojiByName) <https://developers.mattermost.com/api-documentation/#/operations/GetEmojiByName>`_

        """
        return self.client.get(f"/api/v4/emoji/name/{emoji_name}")

    def get_emoji_image(self, emoji_id: str):
        """Get custom emoji image

        emoji_id: Emoji GUID

        `Read in Mattermost API docs (emoji - GetEmojiImage) <https://developers.mattermost.com/api-documentation/#/operations/GetEmojiImage>`_

        """
        return self.client.get(f"/api/v4/emoji/{emoji_id}/image")

    def search_emoji(self, term: str, prefix_only: str | None = None):
        """Search custom emoji

        term: The term to match against the emoji name.
        prefix_only: Set to only search for names starting with the search term.

        `Read in Mattermost API docs (emoji - SearchEmoji) <https://developers.mattermost.com/api-documentation/#/operations/SearchEmoji>`_

        """
        __options = {"term": term, "prefix_only": prefix_only}
        return self.client.post("""/api/v4/emoji/search""", options=__options)

    def autocomplete_emoji(self, name: str):
        """Autocomplete custom emoji

        name: The emoji name to search.

        `Read in Mattermost API docs (emoji - AutocompleteEmoji) <https://developers.mattermost.com/api-documentation/#/operations/AutocompleteEmoji>`_

        """
        __params = {"name": name}
        return self.client.get("""/api/v4/emoji/autocomplete""", params=__params)

    def get_emojis_by_names(self, options: list[str]):
        """Get custom emojis by name
        `Read in Mattermost API docs (emoji - GetEmojisByNames) <https://developers.mattermost.com/api-documentation/#/operations/GetEmojisByNames>`_

        """
        return self.client.post("""/api/v4/emoji/names""", options=options)



from ._base import Base

__all__ = ["Status"]


class Status(Base):

    def get_user_status(self, user_id):
        """Get user status

        user_id: User ID

        `Read in Mattermost API docs (status - GetUserStatus) <https://developers.mattermost.com/api-documentation/#/operations/GetUserStatus>`_

        """
        return self.client.get(f"/api/v4/users/{user_id}/status")

    def update_user_status(self, user_id, options):
        """Update user status

        user_id: User ID
        user_id: User ID
        status: User status, can be ``online``, ``away``, ``offline`` and ``dnd``
        dnd_end_time: Time in epoch seconds at which a dnd status would be unset.

        `Read in Mattermost API docs (status - UpdateUserStatus) <https://developers.mattermost.com/api-documentation/#/operations/UpdateUserStatus>`_

        """
        return self.client.put(f"/api/v4/users/{user_id}/status", options=options)

    def get_users_statuses_by_ids(self, options):
        """Get user statuses by id
        `Read in Mattermost API docs (status - GetUsersStatusesByIds) <https://developers.mattermost.com/api-documentation/#/operations/GetUsersStatusesByIds>`_

        """
        return self.client.post("""/api/v4/users/status/ids""", options=options)

    def update_user_custom_status(self, user_id, options):
        """Update user custom status

        user_id: User ID
        emoji: Any emoji
        text: Any custom status text
        duration: Duration of custom status, can be ``thirty_minutes``, ``one_hour``, ``four_hours``, ``today``, ``this_week`` or ``date_and_time``
        expires_at: The time at which custom status should be expired. It should be in ISO format.

        `Read in Mattermost API docs (status - UpdateUserCustomStatus) <https://developers.mattermost.com/api-documentation/#/operations/UpdateUserCustomStatus>`_

        """
        return self.client.put(f"/api/v4/users/{user_id}/status/custom", options=options)

    def unset_user_custom_status(self, user_id):
        """Unsets user custom status

        user_id: User ID

        `Read in Mattermost API docs (status - UnsetUserCustomStatus) <https://developers.mattermost.com/api-documentation/#/operations/UnsetUserCustomStatus>`_

        """
        return self.client.delete(f"/api/v4/users/{user_id}/status/custom")

    def remove_recent_custom_status(self, user_id, params):
        """Delete user's recent custom status

        user_id: User ID
        emoji: Any emoji
        text: Any custom status text
        duration: Duration of custom status, can be ``thirty_minutes``, ``one_hour``, ``four_hours``, ``today``, ``this_week`` or ``date_and_time``
        expires_at: The time at which custom status should be expired. It should be in ISO format.

        `Read in Mattermost API docs (status - RemoveRecentCustomStatus) <https://developers.mattermost.com/api-documentation/#/operations/RemoveRecentCustomStatus>`_

        """
        return self.client.delete(f"/api/v4/users/{user_id}/status/custom/recent", params=params)

    def post_user_recent_custom_status_delete(self, user_id, options):
        """Delete user's recent custom status

        user_id: User ID
        emoji: Any emoji
        text: Any custom status text
        duration: Duration of custom status, can be ``thirty_minutes``, ``one_hour``, ``four_hours``, ``today``, ``this_week`` or ``date_and_time``
        expires_at: The time at which custom status should be expired. It should be in ISO format.

        `Read in Mattermost API docs (status - PostUserRecentCustomStatusDelete) <https://developers.mattermost.com/api-documentation/#/operations/PostUserRecentCustomStatusDelete>`_

        """
        return self.client.post(f"/api/v4/users/{user_id}/status/custom/recent/delete", options=options)



import logging
import warnings

from ..client import Client

log = logging.getLogger("mattermostautodriver.api")
log.setLevel(logging.INFO)


class BaseDriver:
    """
    Contains the client, api and provides you with functions for
    login, logout and initializing a websocket connection.
    """

    default_options = {
        "scheme": "https",
        "url": "localhost",
        "port": 8065,
        "verify": True,
        "timeout": 30,
        "request_timeout": None,
        "login_id": None,
        "password": None,
        "token": None,
        "mfa_token": None,
        "auth": None,
        "keepalive": False,
        "keepalive_delay": 5,
        "websocket_kw_args": None,
        "debug": False,
        "http2": False,
        "proxy": None,
    }
    """
    Required options
        - url

    Either
        - login_id
        - password

    Or
        - token (https://docs.mattermost.com/developer/personal-access-tokens.html)

    Optional
        - scheme ('https')
        - port (8065)
        - verify (True)
        - timeout (30)
        - request_timeout (None)
        - mfa_token (None)
        - auth (None)
        - debug (False)
    """

    def __init__(self, options=None, client_cls=Client, *args, **kwargs):
        """
        :param options: A dict with the values from `default_options`
        :type options: dict
        """
        self.options = self.default_options.copy()
        if options is not None:
            self.options.update(options)
        self.driver = self.options
        if self.options["debug"]:
            log.setLevel(logging.DEBUG)
            log.warning(
                "Careful!!\nSetting debug to True, will reveal your password in the log output if you do driver.login()!\nThis is NOT for production!"
            )
        self.client = client_cls(self.options)
        self.websocket = None

    def disconnect(self):
        """Disconnects the driver from the server, stopping the websocket event loop."""
        if self.websocket is not None:
            self.websocket.disconnect()



from ._base import Base
from typing import Any, BinaryIO

__all__ = ["Playbooks"]


class Playbooks(Base):

    def get_playbooks(
        self,
        team_id: str,
        page: int | None = 0,
        per_page: int | None = 1000,
        sort: str | None = "title",
        direction: str | None = "asc",
        with_archived: bool | None = False,
    ):
        """List all playbooks

        team_id: ID of the team to filter by.
        page: Zero-based index of the page to request.
        per_page: Number of playbooks to return per page.
        sort: Field to sort the returned playbooks by title, number of stages or total number of steps.
        direction: Direction (ascending or descending) followed by the sorting of the playbooks.
        with_archived: Includes archived playbooks in the result.

        `Read in Mattermost API docs (playbooks - getPlaybooks) <https://developers.mattermost.com/api-documentation/#/operations/getPlaybooks>`_

        """
        __params = {
            "team_id": team_id,
            "page": page,
            "per_page": per_page,
            "sort": sort,
            "direction": direction,
            "with_archived": with_archived,
        }
        return self.client.get("""/plugins/playbooks/api/v0/playbooks""", params=__params)

    def create_playbook(
        self,
        title: str,
        team_id: str,
        create_public_playbook_run: bool,
        checklists: list[dict[str, Any]],
        member_ids: list[str],
        description: str | None = None,
        public: bool | None = None,
        broadcast_channel_ids: list[str] | None = None,
        invited_user_ids: list[str] | None = None,
        invite_users_enabled: bool | None = None,
        default_owner_id: str | None = None,
        default_owner_enabled: str | None = None,
        announcement_channel_id: str | None = None,
        announcement_channel_enabled: bool | None = None,
        webhook_on_creation_url: str | None = None,
        webhook_on_creation_enabled: bool | None = None,
        webhook_on_status_update_url: str | None = None,
        webhook_on_status_update_enabled: bool | None = None,
    ):
        """Create a playbook

        title: The title of the playbook.
        description: The description of the playbook.
        team_id: The identifier of the team where the playbook is in.
        create_public_playbook_run: A boolean indicating whether the playbook runs created from this playbook should be public or private.
        public: A boolean indicating whether the playbook is licensed as public or private. Required 'true' for free tier.
        checklists: The stages defined by this playbook.
        member_ids: The identifiers of all the users that are members of this playbook.
        broadcast_channel_ids: The IDs of the channels where all the status updates will be broadcasted. The team of the broadcast channel must be the same as the playbook's team.
        invited_user_ids: A list with the IDs of the members to be automatically invited to the playbook run's channel as soon as the playbook run is created.
        invite_users_enabled: Boolean that indicates whether the members declared in invited_user_ids will be automatically invited.
        default_owner_id: User ID of the member that will be automatically assigned as owner as soon as the playbook run is created. If the member is not part of the playbook run's channel or is not included in the invited_user_ids list, they will be automatically invited to the channel.
        default_owner_enabled: Boolean that indicates whether the member declared in default_owner_id will be automatically assigned as owner.
        announcement_channel_id: ID of the channel where the playbook run will be automatically announced as soon as the playbook run is created.
        announcement_channel_enabled: Boolean that indicates whether the playbook run creation will be announced in the channel declared in announcement_channel_id.
        webhook_on_creation_url: An absolute URL where a POST request will be sent as soon as the playbook run is created. The allowed protocols are HTTP and HTTPS.
        webhook_on_creation_enabled: Boolean that indicates whether the webhook declared in webhook_on_creation_url will be automatically sent.
        webhook_on_status_update_url: An absolute URL where a POST request will be sent as soon as the playbook run's status is updated. The allowed protocols are HTTP and HTTPS.
        webhook_on_status_update_enabled: Boolean that indicates whether the webhook declared in webhook_on_status_update_url will be automatically sent.

        `Read in Mattermost API docs (playbooks - createPlaybook) <https://developers.mattermost.com/api-documentation/#/operations/createPlaybook>`_

        """
        __options = {
            "title": title,
            "description": description,
            "team_id": team_id,
            "create_public_playbook_run": create_public_playbook_run,
            "public": public,
            "checklists": checklists,
            "member_ids": member_ids,
            "broadcast_channel_ids": broadcast_channel_ids,
            "invited_user_ids": invited_user_ids,
            "invite_users_enabled": invite_users_enabled,
            "default_owner_id": default_owner_id,
            "default_owner_enabled": default_owner_enabled,
            "announcement_channel_id": announcement_channel_id,
            "announcement_channel_enabled": announcement_channel_enabled,
            "webhook_on_creation_url": webhook_on_creation_url,
            "webhook_on_creation_enabled": webhook_on_creation_enabled,
            "webhook_on_status_update_url": webhook_on_status_update_url,
            "webhook_on_status_update_enabled": webhook_on_status_update_enabled,
        }
        return self.client.post("""/plugins/playbooks/api/v0/playbooks""", options=__options)

    def get_playbook(self, id: str):
        """Get a playbook

        id: ID of the playbook to retrieve.

        `Read in Mattermost API docs (playbooks - getPlaybook) <https://developers.mattermost.com/api-documentation/#/operations/getPlaybook>`_

        """
        return self.client.get(f"/plugins/playbooks/api/v0/playbooks/{id}")

    def update_playbook(self, id: str, options: Any | None = None):
        """Update a playbook

        id: ID of the playbook to update.

        `Read in Mattermost API docs (playbooks - updatePlaybook) <https://developers.mattermost.com/api-documentation/#/operations/updatePlaybook>`_

        """
        return self.client.put(f"/plugins/playbooks/api/v0/playbooks/{id}", options=options)

    def delete_playbook(self, id: str):
        """Delete a playbook

        id: ID of the playbook to delete.

        `Read in Mattermost API docs (playbooks - deletePlaybook) <https://developers.mattermost.com/api-documentation/#/operations/deletePlaybook>`_

        """
        return self.client.delete(f"/plugins/playbooks/api/v0/playbooks/{id}")

    def get_playbook_property_fields(self, id: str, updated_since: int | None = None):
        """Get property fields for a playbook

        id: ID of the playbook to retrieve property fields from.
        updated_since: Filter results to only include property fields updated after this timestamp (Unix time in milliseconds).

        `Read in Mattermost API docs (playbooks - getPlaybookPropertyFields) <https://developers.mattermost.com/api-documentation/#/operations/getPlaybookPropertyFields>`_

        """
        __params = {"updated_since": updated_since}
        return self.client.get(f"/plugins/playbooks/api/v0/playbooks/{id}/property_fields", params=__params)

    def create_playbook_property_field(self, id: str, options: Any | None = None):
        """Create a property field for a playbook

        id: ID of the playbook to create a property field for.

        `Read in Mattermost API docs (playbooks - createPlaybookPropertyField) <https://developers.mattermost.com/api-documentation/#/operations/createPlaybookPropertyField>`_

        """
        return self.client.post(f"/plugins/playbooks/api/v0/playbooks/{id}/property_fields", options=options)

    def update_playbook_property_field(self, id: str, field_id: str, options: Any | None = None):
        """Update a property field for a playbook

        id: ID of the playbook containing the property field.
        field_id: ID of the property field to update.

        `Read in Mattermost API docs (playbooks - updatePlaybookPropertyField) <https://developers.mattermost.com/api-documentation/#/operations/updatePlaybookPropertyField>`_

        """
        return self.client.put(f"/plugins/playbooks/api/v0/playbooks/{id}/property_fields/{field_id}", options=options)

    def delete_playbook_property_field(self, id: str, field_id: str):
        """Delete a property field for a playbook

        id: ID of the playbook containing the property field.
        field_id: ID of the property field to delete.

        `Read in Mattermost API docs (playbooks - deletePlaybookPropertyField) <https://developers.mattermost.com/api-documentation/#/operations/deletePlaybookPropertyField>`_

        """
        return self.client.delete(f"/plugins/playbooks/api/v0/playbooks/{id}/property_fields/{field_id}")

    def reorder_playbook_property_fields(self, id: str, field_id: str, target_position: int):
        """Reorder property fields for a playbook

        id: ID of the playbook.
        field_id: ID of the property field to move.
        target_position: Target position index (zero-based) where the field should be moved.

        `Read in Mattermost API docs (playbooks - reorderPlaybookPropertyFields) <https://developers.mattermost.com/api-documentation/#/operations/reorderPlaybookPropertyFields>`_

        """
        __options = {"field_id": field_id, "target_position": target_position}
        return self.client.post(f"/plugins/playbooks/api/v0/playbooks/{id}/property_fields/reorder", options=__options)
